import OCP.StepToGeom
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.Geom
import OCP.gp
import OCP.TColStd
import OCP.StepGeom
import OCP.StepRepr
import OCP.Geom2d
__all__  = [
"StepToGeom"
]
class StepToGeom():
    """
    This class provides static methods to convert STEP geometric entities to OCCT. The methods returning handles will return null handle in case of error. The methods returning boolean will return True if succeeded and False if error.
    """
    @staticmethod
    def MakeAxis1Placement_s(SA : OCP.StepGeom.StepGeom_Axis1Placement,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom.Geom_Axis1Placement: ...
    @staticmethod
    @overload
    def MakeAxis2Placement_s(SA : OCP.StepGeom.StepGeom_Axis2Placement3d,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom.Geom_Axis2Placement: ...
    @staticmethod
    @overload
    def MakeAxis2Placement_s(SP : OCP.StepGeom.StepGeom_SuParameters) -> OCP.Geom.Geom_Axis2Placement: ...
    @staticmethod
    def MakeAxisPlacement_s(SA : OCP.StepGeom.StepGeom_Axis2Placement2d,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom2d.Geom2d_AxisPlacement: ...
    @staticmethod
    def MakeBSplineCurve2d_s(SC : OCP.StepGeom.StepGeom_BSplineCurve,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom2d.Geom2d_BSplineCurve: ...
    @staticmethod
    def MakeBSplineCurve_s(SC : OCP.StepGeom.StepGeom_BSplineCurve,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom.Geom_BSplineCurve: ...
    @staticmethod
    def MakeBSplineSurface_s(SS : OCP.StepGeom.StepGeom_BSplineSurface,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom.Geom_BSplineSurface: ...
    @staticmethod
    def MakeBoundedCurve2d_s(SC : OCP.StepGeom.StepGeom_BoundedCurve,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom2d.Geom2d_BoundedCurve: ...
    @staticmethod
    def MakeBoundedCurve_s(SC : OCP.StepGeom.StepGeom_BoundedCurve,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom.Geom_BoundedCurve: ...
    @staticmethod
    def MakeBoundedSurface_s(SS : OCP.StepGeom.StepGeom_BoundedSurface,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom.Geom_BoundedSurface: ...
    @staticmethod
    def MakeCartesianPoint2d_s(SP : OCP.StepGeom.StepGeom_CartesianPoint,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom2d.Geom2d_CartesianPoint: ...
    @staticmethod
    def MakeCartesianPoint_s(SP : OCP.StepGeom.StepGeom_CartesianPoint,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom.Geom_CartesianPoint: ...
    @staticmethod
    def MakeCircle2d_s(SC : OCP.StepGeom.StepGeom_Circle,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom2d.Geom2d_Circle: ...
    @staticmethod
    def MakeCircle_s(SC : OCP.StepGeom.StepGeom_Circle,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom.Geom_Circle: ...
    @staticmethod
    def MakeConic2d_s(SC : OCP.StepGeom.StepGeom_Conic,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom2d.Geom2d_Conic: ...
    @staticmethod
    def MakeConic_s(SC : OCP.StepGeom.StepGeom_Conic,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom.Geom_Conic: ...
    @staticmethod
    def MakeConicalSurface_s(SS : OCP.StepGeom.StepGeom_ConicalSurface,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom.Geom_ConicalSurface: ...
    @staticmethod
    def MakeCurve2d_s(SC : OCP.StepGeom.StepGeom_Curve,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom2d.Geom2d_Curve: ...
    @staticmethod
    def MakeCurve_s(SC : OCP.StepGeom.StepGeom_Curve,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom.Geom_Curve: ...
    @staticmethod
    def MakeCylindricalSurface_s(SS : OCP.StepGeom.StepGeom_CylindricalSurface,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom.Geom_CylindricalSurface: ...
    @staticmethod
    def MakeDirection2d_s(SD : OCP.StepGeom.StepGeom_Direction) -> OCP.Geom2d.Geom2d_Direction: ...
    @staticmethod
    def MakeDirection_s(SD : OCP.StepGeom.StepGeom_Direction) -> OCP.Geom.Geom_Direction: ...
    @staticmethod
    def MakeElementarySurface_s(SS : OCP.StepGeom.StepGeom_ElementarySurface,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom.Geom_ElementarySurface: ...
    @staticmethod
    def MakeEllipse2d_s(SC : OCP.StepGeom.StepGeom_Ellipse,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom2d.Geom2d_Ellipse: ...
    @staticmethod
    def MakeEllipse_s(SC : OCP.StepGeom.StepGeom_Ellipse,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom.Geom_Ellipse: ...
    @staticmethod
    def MakeHyperbola2d_s(SC : OCP.StepGeom.StepGeom_Hyperbola,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom2d.Geom2d_Hyperbola: ...
    @staticmethod
    def MakeHyperbola_s(SC : OCP.StepGeom.StepGeom_Hyperbola,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom.Geom_Hyperbola: ...
    @staticmethod
    def MakeLine2d_s(SC : OCP.StepGeom.StepGeom_Line,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom2d.Geom2d_Line: ...
    @staticmethod
    def MakeLine_s(SC : OCP.StepGeom.StepGeom_Line,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom.Geom_Line: ...
    @staticmethod
    def MakeParabola2d_s(SC : OCP.StepGeom.StepGeom_Parabola,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom2d.Geom2d_Parabola: ...
    @staticmethod
    def MakeParabola_s(SC : OCP.StepGeom.StepGeom_Parabola,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom.Geom_Parabola: ...
    @staticmethod
    def MakePlane_s(SP : OCP.StepGeom.StepGeom_Plane,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom.Geom_Plane: ...
    @staticmethod
    def MakePolyline2d_s(SPL : OCP.StepGeom.StepGeom_Polyline,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom2d.Geom2d_BSplineCurve: ...
    @staticmethod
    def MakePolyline_s(SPL : OCP.StepGeom.StepGeom_Polyline,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom.Geom_BSplineCurve: ...
    @staticmethod
    def MakeRectangularTrimmedSurface_s(SS : OCP.StepGeom.StepGeom_RectangularTrimmedSurface,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom.Geom_RectangularTrimmedSurface: ...
    @staticmethod
    def MakeSphericalSurface_s(SS : OCP.StepGeom.StepGeom_SphericalSurface,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom.Geom_SphericalSurface: ...
    @staticmethod
    def MakeSurfaceOfLinearExtrusion_s(SS : OCP.StepGeom.StepGeom_SurfaceOfLinearExtrusion,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom.Geom_SurfaceOfLinearExtrusion: ...
    @staticmethod
    def MakeSurfaceOfRevolution_s(SS : OCP.StepGeom.StepGeom_SurfaceOfRevolution,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom.Geom_SurfaceOfRevolution: ...
    @staticmethod
    def MakeSurface_s(SS : OCP.StepGeom.StepGeom_Surface,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom.Geom_Surface: ...
    @staticmethod
    def MakeSweptSurface_s(SS : OCP.StepGeom.StepGeom_SweptSurface,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom.Geom_SweptSurface: ...
    @staticmethod
    def MakeToroidalSurface_s(SS : OCP.StepGeom.StepGeom_ToroidalSurface,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom.Geom_ToroidalSurface: ...
    @staticmethod
    def MakeTransformation2d_s(SCTO : OCP.StepGeom.StepGeom_CartesianTransformationOperator2d,CT : OCP.gp.gp_Trsf2d,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> bool: ...
    @staticmethod
    def MakeTransformation3d_s(SCTO : OCP.StepGeom.StepGeom_CartesianTransformationOperator3d,CT : OCP.gp.gp_Trsf,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> bool: ...
    @staticmethod
    def MakeTrimmedCurve2d_s(SC : OCP.StepGeom.StepGeom_TrimmedCurve,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom2d.Geom2d_BSplineCurve: ...
    @staticmethod
    def MakeTrimmedCurve_s(SC : OCP.StepGeom.StepGeom_TrimmedCurve,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom.Geom_TrimmedCurve: ...
    @staticmethod
    def MakeVectorWithMagnitude2d_s(SV : OCP.StepGeom.StepGeom_Vector) -> OCP.Geom2d.Geom2d_VectorWithMagnitude: ...
    @staticmethod
    def MakeVectorWithMagnitude_s(SV : OCP.StepGeom.StepGeom_Vector,theLocalFactors : OCP.StepData.StepData_Factors=OCP.StepData.StepData_Factors) -> OCP.Geom.Geom_VectorWithMagnitude: ...
    @staticmethod
    def MakeYprRotation_s(SR : StepKinematics_SpatialRotation,theCntxt : OCP.StepRepr.StepRepr_GlobalUnitAssignedContext) -> OCP.TColStd.TColStd_HArray1OfReal: ...
    def __init__(self) -> None: ...
    pass



import OCP.Geom2dLProp
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.LProp
import OCP.math
import OCP.Geom2d
import OCP.gp
__all__  = [
"Geom2dLProp_CLProps2d",
"Geom2dLProp_CurAndInf2d",
"Geom2dLProp_Curve2dTool",
"Geom2dLProp_FuncCurExt",
"Geom2dLProp_FuncCurNul",
"Geom2dLProp_NumericCurInf2d"
]
class Geom2dLProp_CLProps2d():
    def CentreOfCurvature(self,P : OCP.gp.gp_Pnt2d) -> None: 
        """
        Returns the centre of curvature <P>.
        """
    def Curvature(self) -> float: 
        """
        Returns the curvature.
        """
    def D1(self) -> OCP.gp.gp_Vec2d: 
        """
        Returns the first derivative. The derivative is computed if it has not been yet.
        """
    def D2(self) -> OCP.gp.gp_Vec2d: 
        """
        Returns the second derivative. The derivative is computed if it has not been yet.
        """
    def D3(self) -> OCP.gp.gp_Vec2d: 
        """
        Returns the third derivative. The derivative is computed if it has not been yet.
        """
    def IsTangentDefined(self) -> bool: 
        """
        Returns True if the tangent is defined. For example, the tangent is not defined if the three first derivatives are all null.
        """
    def Normal(self,N : OCP.gp.gp_Dir2d) -> None: 
        """
        Returns the normal direction <N>.
        """
    def SetCurve(self,C : OCP.Geom2d.Geom2d_Curve) -> None: 
        """
        Initializes the local properties of the curve for the new curve.
        """
    def SetParameter(self,U : float) -> None: 
        """
        Initializes the local properties of the curve for the parameter value <U>.
        """
    def Tangent(self,D : OCP.gp.gp_Dir2d) -> None: 
        """
        output the tangent direction <D>
        """
    def Value(self) -> OCP.gp.gp_Pnt2d: 
        """
        Returns the Point.
        """
    @overload
    def __init__(self,C : OCP.Geom2d.Geom2d_Curve,N : int,Resolution : float) -> None: ...
    @overload
    def __init__(self,C : OCP.Geom2d.Geom2d_Curve,U : float,N : int,Resolution : float) -> None: ...
    @overload
    def __init__(self,N : int,Resolution : float) -> None: ...
    pass
class Geom2dLProp_CurAndInf2d(OCP.LProp.LProp_CurAndInf):
    """
    An algorithm for computing local properties of a curve. These properties include: - the maximum and minimum curvatures - the inflection points. A CurAndInf2d object provides the framework for: - defining the curve to be analyzed - implementing the computation algorithms - consulting the results.
    """
    def AddExtCur(self,Param : float,IsMin : bool) -> None: ...
    def AddInflection(self,Param : float) -> None: ...
    def Clear(self) -> None: ...
    def IsDone(self) -> bool: 
        """
        True if the solutions are found.
        """
    def IsEmpty(self) -> bool: ...
    def NbPoints(self) -> int: 
        """
        Returns the number of points. The Points are stored to increasing parameter.
        """
    def Parameter(self,N : int) -> float: 
        """
        Returns the parameter of the Nth point. raises if N not in the range [1,NbPoints()]
        """
    def Perform(self,C : OCP.Geom2d.Geom2d_Curve) -> None: 
        """
        For the curve C, Computes both the inflection points and the maximum and minimum curvatures.
        """
    def PerformCurExt(self,C : OCP.Geom2d.Geom2d_Curve) -> None: 
        """
        For the curve C, Computes the locals extremas of curvature.
        """
    def PerformInf(self,C : OCP.Geom2d.Geom2d_Curve) -> None: 
        """
        For the curve C, Computes the inflections. After computation, the following functions can be used: - IsDone to check if the computation was successful - NbPoints to obtain the number of computed particular points - Parameter to obtain the parameter on the curve for each particular point - Type to check if the point is an inflection point or an extremum of curvature of the curve C. Warning These functions can be used to analyze a series of curves, however it is necessary to clear the table of results between each computation.
        """
    def Type(self,N : int) -> OCP.LProp.LProp_CIType: 
        """
        Returns - MinCur if the Nth parameter corresponds to a minimum of the radius of curvature. - MaxCur if the Nth parameter corresponds to a maximum of the radius of curvature. - Inflection if the parameter corresponds to a point of inflection. raises if N not in the range [1,NbPoints()]
        """
    def __init__(self) -> None: ...
    pass
class Geom2dLProp_Curve2dTool():
    @staticmethod
    def Continuity_s(C : OCP.Geom2d.Geom2d_Curve) -> int: 
        """
        returns the order of continuity of the curve <C>. returns 1 : first derivative only is computable returns 2 : first and second derivative only are computable. returns 3 : first, second and third are computable.
        """
    @staticmethod
    def D1_s(C : OCP.Geom2d.Geom2d_Curve,U : float,P : OCP.gp.gp_Pnt2d,V1 : OCP.gp.gp_Vec2d) -> None: 
        """
        Computes the point <P> and first derivative <V1> of parameter <U> on the curve <C>.
        """
    @staticmethod
    def D2_s(C : OCP.Geom2d.Geom2d_Curve,U : float,P : OCP.gp.gp_Pnt2d,V1 : OCP.gp.gp_Vec2d,V2 : OCP.gp.gp_Vec2d) -> None: 
        """
        Computes the point <P>, the first derivative <V1> and second derivative <V2> of parameter <U> on the curve <C>.
        """
    @staticmethod
    def D3_s(C : OCP.Geom2d.Geom2d_Curve,U : float,P : OCP.gp.gp_Pnt2d,V1 : OCP.gp.gp_Vec2d,V2 : OCP.gp.gp_Vec2d,V3 : OCP.gp.gp_Vec2d) -> None: 
        """
        Computes the point <P>, the first derivative <V1>, the second derivative <V2> and third derivative <V3> of parameter <U> on the curve <C>.
        """
    @staticmethod
    def FirstParameter_s(C : OCP.Geom2d.Geom2d_Curve) -> float: 
        """
        returns the first parameter bound of the curve.
        """
    @staticmethod
    def LastParameter_s(C : OCP.Geom2d.Geom2d_Curve) -> float: 
        """
        returns the last parameter bound of the curve. FirstParameter must be less than LastParameter.
        """
    @staticmethod
    def Value_s(C : OCP.Geom2d.Geom2d_Curve,U : float,P : OCP.gp.gp_Pnt2d) -> None: 
        """
        Computes the point <P> of parameter <U> on the curve <C>.
        """
    def __init__(self) -> None: ...
    pass
class Geom2dLProp_FuncCurExt(OCP.math.math_FunctionWithDerivative, OCP.math.math_Function):
    """
    Function used to find the extremas of curvature in 2d.
    """
    def Derivative(self,X : float,D : float) -> bool: 
        """
        Returns the derivative for the variable <X>.
        """
    def GetStateNumber(self) -> int: 
        """
        returns the state of the function corresponding to the latest call of any methods associated with the function. This function is called by each of the algorithms described later which defined the function Integer Algorithm::StateNumber(). The algorithm has the responsibility to call this function when it has found a solution (i.e. a root or a minimum) and has to maintain the association between the solution found and this StateNumber. Byu default, this method returns 0 (which means for the algorithm: no state has been saved). It is the responsibility of the programmer to decide if he needs to save the current state of the function and to return an Integer that allows retrieval of the state.
        """
    def IsMinKC(self,Param : float) -> bool: 
        """
        True if Param corresponds to a minus of the radius of curvature.
        """
    def Value(self,X : float,F : float) -> bool: 
        """
        Returns the value for the variable <X>.
        """
    def Values(self,X : float,F : float,D : float) -> bool: 
        """
        Returns the value of the function and the derivative for the variable <X>.
        """
    def __init__(self,C : OCP.Geom2d.Geom2d_Curve,Tol : float) -> None: ...
    pass
class Geom2dLProp_FuncCurNul(OCP.math.math_FunctionWithDerivative, OCP.math.math_Function):
    """
    Function used to find the inflections in 2d.
    """
    def Derivative(self,X : float,D : float) -> bool: 
        """
        Returns the derivative for the variable <X>
        """
    def GetStateNumber(self) -> int: 
        """
        returns the state of the function corresponding to the latest call of any methods associated with the function. This function is called by each of the algorithms described later which defined the function Integer Algorithm::StateNumber(). The algorithm has the responsibility to call this function when it has found a solution (i.e. a root or a minimum) and has to maintain the association between the solution found and this StateNumber. Byu default, this method returns 0 (which means for the algorithm: no state has been saved). It is the responsibility of the programmer to decide if he needs to save the current state of the function and to return an Integer that allows retrieval of the state.
        """
    def Value(self,X : float,F : float) -> bool: 
        """
        Returns the value for the variable <X>.
        """
    def Values(self,X : float,F : float,D : float) -> bool: 
        """
        Returns the value of the function and the derivative for the variable <X>.
        """
    def __init__(self,C : OCP.Geom2d.Geom2d_Curve) -> None: ...
    pass
class Geom2dLProp_NumericCurInf2d():
    """
    Computes the locals extremas of curvature and the inflections of a bounded curve in 2d.
    """
    def IsDone(self) -> bool: 
        """
        True if the solutions are found.
        """
    @overload
    def PerformCurExt(self,C : OCP.Geom2d.Geom2d_Curve,Result : OCP.LProp.LProp_CurAndInf) -> None: 
        """
        Computes the locals extremas of curvature.

        Computes the locals extremas of curvature. in the interval of parameters [UMin,UMax].
        """
    @overload
    def PerformCurExt(self,C : OCP.Geom2d.Geom2d_Curve,UMin : float,UMax : float,Result : OCP.LProp.LProp_CurAndInf) -> None: ...
    @overload
    def PerformInf(self,C : OCP.Geom2d.Geom2d_Curve,Result : OCP.LProp.LProp_CurAndInf) -> None: 
        """
        Computes the inflections.

        Computes the inflections in the interval of parameters [UMin,UMax].
        """
    @overload
    def PerformInf(self,C : OCP.Geom2d.Geom2d_Curve,UMin : float,UMax : float,Result : OCP.LProp.LProp_CurAndInf) -> None: ...
    def __init__(self) -> None: ...
    pass



import OCP.OpenGl.OpenGl_Raytrace
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.OpenGl
__all__  = [
"IsRaytracedElement",
"IsRaytracedGroup"
]
@overload
def IsRaytracedElement(theNode : OCP.OpenGl.OpenGl_ElementNode) -> bool:
    """
    Checks to see if the element contains ray-trace geometry.

    Checks to see if the element contains ray-trace geometry.
    """
@overload
def IsRaytracedElement(theElement : OCP.OpenGl.OpenGl_Element) -> bool:
    pass
def IsRaytracedGroup(theGroup : OCP.OpenGl.OpenGl_Group) -> bool:
    """
    Checks to see if the group contains ray-trace geometry.
    """



import OCP.FilletSurf
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.gp
import OCP.Geom
import OCP.TopTools
import OCP.TopoDS
import OCP.Law
import OCP.ChFiDS
import OCP.ChFi3d
import OCP.GeomAbs
import OCP.Geom2d
import OCP.TopOpeBRepBuild
import OCP.Adaptor3d
__all__  = [
"FilletSurf_Builder",
"FilletSurf_ErrorTypeStatus",
"FilletSurf_InternalBuilder",
"FilletSurf_StatusDone",
"FilletSurf_StatusType",
"FilletSurf_EdgeNotG1",
"FilletSurf_EdgeNotOnShape",
"FilletSurf_EmptyList",
"FilletSurf_FacesNotG1",
"FilletSurf_IsNotOk",
"FilletSurf_IsOk",
"FilletSurf_IsPartial",
"FilletSurf_NoExtremityOnEdge",
"FilletSurf_NotSharpEdge",
"FilletSurf_OneExtremityOnEdge",
"FilletSurf_PbFilletCompute",
"FilletSurf_TwoExtremityOnEdge"
]
class FilletSurf_Builder():
    """
    API giving the following geometric information about fillets list of corresponding NUBS surfaces for each surface: the 2 support faces on each face: the 3d curve and the corresponding 2d curve the 2d curves on the fillet status of start and end section of the fillet first and last parameter on edge of the fillet.
    """
    def CurveOnFace1(self,Index : int) -> OCP.Geom.Geom_Curve: 
        """
        gives the 3d curve of SurfaceFillet(Index) on SupportFace1(Index)
        """
    def CurveOnFace2(self,Index : int) -> OCP.Geom.Geom_Curve: 
        """
        gives the 3d curve of SurfaceFillet(Index) on SupportFace2(Index)
        """
    def EndSectionStatus(self) -> FilletSurf_StatusType: ...
    def FirstParameter(self) -> float: 
        """
        gives the parameter of the fillet on the first edge.
        """
    def IsDone(self) -> FilletSurf_StatusDone: 
        """
        gives the status about the computation of the fillet returns: IsOK :no problem during the computation IsNotOk: no result is produced IsPartial: the result is partial
        """
    def LastParameter(self) -> float: 
        """
        gives the parameter of the fillet on the last edge
        """
    def NbSection(self,IndexSurf : int) -> int: ...
    def NbSurface(self) -> int: 
        """
        gives the number of NUBS surfaces of the Fillet.
        """
    def PCurve1OnFillet(self,Index : int) -> OCP.Geom2d.Geom2d_Curve: 
        """
        gives the PCurve associated to CurveOnFace1(Index) on the Fillet
        """
    def PCurve2OnFillet(self,Index : int) -> OCP.Geom2d.Geom2d_Curve: 
        """
        gives the PCurve associated to CurveOnSup2(Index) on the fillet
        """
    def PCurveOnFace1(self,Index : int) -> OCP.Geom2d.Geom2d_Curve: 
        """
        gives the PCurve associated to CurvOnSup1(Index) on the support face
        """
    def PCurveOnFace2(self,Index : int) -> OCP.Geom2d.Geom2d_Curve: 
        """
        gives the PCurve associated to CurveOnSup2(Index) on the support face
        """
    def Perform(self) -> None: 
        """
        ---Purpose computation of the fillet (list of NUBS)
        """
    def Section(self,IndexSurf : int,IndexSec : int,Circ : OCP.Geom.Geom_TrimmedCurve) -> Any: ...
    def Simulate(self) -> None: ...
    def StartSectionStatus(self) -> FilletSurf_StatusType: ...
    def StatusError(self) -> FilletSurf_ErrorTypeStatus: 
        """
        gives information about error status if IsDone=IsNotOk returns EdgeNotG1: the edges are not G1 FacesNotG1 : two connected faces on a same support are not G1 EdgeNotOnShape: the edge is not on shape NotSharpEdge: the edge is not sharp PbFilletCompute: problem during the computation of the fillet
        """
    def SupportFace1(self,Index : int) -> OCP.TopoDS.TopoDS_Face: 
        """
        gives the first support face relative to SurfaceFillet(Index);
        """
    def SupportFace2(self,Index : int) -> OCP.TopoDS.TopoDS_Face: 
        """
        gives the second support face relative to SurfaceFillet(Index);
        """
    def SurfaceFillet(self,Index : int) -> OCP.Geom.Geom_Surface: 
        """
        gives the NUBS surface of index Index.
        """
    def TolApp3d(self,Index : int) -> float: 
        """
        gives the 3d tolerance reached during approximation of surface of index Index
        """
    def __init__(self,S : OCP.TopoDS.TopoDS_Shape,E : OCP.TopTools.TopTools_ListOfShape,R : float,Ta : float=0.01,Tapp3d : float=0.0001,Tapp2d : float=1e-05) -> None: ...
    pass
class FilletSurf_ErrorTypeStatus():
    """
    Members:

      FilletSurf_EmptyList

      FilletSurf_EdgeNotG1

      FilletSurf_FacesNotG1

      FilletSurf_EdgeNotOnShape

      FilletSurf_NotSharpEdge

      FilletSurf_PbFilletCompute
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    FilletSurf_EdgeNotG1: OCP.FilletSurf.FilletSurf_ErrorTypeStatus # value = <FilletSurf_ErrorTypeStatus.FilletSurf_EdgeNotG1: 1>
    FilletSurf_EdgeNotOnShape: OCP.FilletSurf.FilletSurf_ErrorTypeStatus # value = <FilletSurf_ErrorTypeStatus.FilletSurf_EdgeNotOnShape: 3>
    FilletSurf_EmptyList: OCP.FilletSurf.FilletSurf_ErrorTypeStatus # value = <FilletSurf_ErrorTypeStatus.FilletSurf_EmptyList: 0>
    FilletSurf_FacesNotG1: OCP.FilletSurf.FilletSurf_ErrorTypeStatus # value = <FilletSurf_ErrorTypeStatus.FilletSurf_FacesNotG1: 2>
    FilletSurf_NotSharpEdge: OCP.FilletSurf.FilletSurf_ErrorTypeStatus # value = <FilletSurf_ErrorTypeStatus.FilletSurf_NotSharpEdge: 4>
    FilletSurf_PbFilletCompute: OCP.FilletSurf.FilletSurf_ErrorTypeStatus # value = <FilletSurf_ErrorTypeStatus.FilletSurf_PbFilletCompute: 5>
    __entries: dict # value = {'FilletSurf_EmptyList': (<FilletSurf_ErrorTypeStatus.FilletSurf_EmptyList: 0>, None), 'FilletSurf_EdgeNotG1': (<FilletSurf_ErrorTypeStatus.FilletSurf_EdgeNotG1: 1>, None), 'FilletSurf_FacesNotG1': (<FilletSurf_ErrorTypeStatus.FilletSurf_FacesNotG1: 2>, None), 'FilletSurf_EdgeNotOnShape': (<FilletSurf_ErrorTypeStatus.FilletSurf_EdgeNotOnShape: 3>, None), 'FilletSurf_NotSharpEdge': (<FilletSurf_ErrorTypeStatus.FilletSurf_NotSharpEdge: 4>, None), 'FilletSurf_PbFilletCompute': (<FilletSurf_ErrorTypeStatus.FilletSurf_PbFilletCompute: 5>, None)}
    __members__: dict # value = {'FilletSurf_EmptyList': <FilletSurf_ErrorTypeStatus.FilletSurf_EmptyList: 0>, 'FilletSurf_EdgeNotG1': <FilletSurf_ErrorTypeStatus.FilletSurf_EdgeNotG1: 1>, 'FilletSurf_FacesNotG1': <FilletSurf_ErrorTypeStatus.FilletSurf_FacesNotG1: 2>, 'FilletSurf_EdgeNotOnShape': <FilletSurf_ErrorTypeStatus.FilletSurf_EdgeNotOnShape: 3>, 'FilletSurf_NotSharpEdge': <FilletSurf_ErrorTypeStatus.FilletSurf_NotSharpEdge: 4>, 'FilletSurf_PbFilletCompute': <FilletSurf_ErrorTypeStatus.FilletSurf_PbFilletCompute: 5>}
    pass
class FilletSurf_InternalBuilder(OCP.ChFi3d.ChFi3d_FilBuilder, OCP.ChFi3d.ChFi3d_Builder):
    """
    This class is private. It is used by the class Builder from FilletSurf. It computes geometric information about fillets.
    """
    def Abscissa(self,IC : int,V : OCP.TopoDS.TopoDS_Vertex) -> float: 
        """
        returns the abscissa of the vertex V on the contour of index IC.
        """
    def Add(self,E : OCP.TopTools.TopTools_ListOfShape,R : float) -> int: 
        """
        Initializes the contour with a list of Edges 0 : no problem 1 : empty list 2 : the edges are not G1 3 : two connected faces on a same support are not G1 4 : the edge is not on shape 5 : NotSharpEdge: the edge is not sharp
        """
    def BadShape(self) -> OCP.TopoDS.TopoDS_Shape: 
        """
        if (HasResult()) returns partial result if (!HasResult())
        """
    def Builder(self) -> OCP.TopOpeBRepBuild.TopOpeBRepBuild_HBuilder: 
        """
        Returns the Builder of topologic operations.
        """
    def Closed(self,IC : int) -> bool: 
        """
        returns true if the contour of index IC is closed
        """
    def ClosedAndTangent(self,IC : int) -> bool: 
        """
        returns true if the contour of index IC is closed an tangent.
        """
    def Compute(self) -> None: 
        """
        general calculation of geometry on all edges, topologic reconstruction.
        """
    def ComputedSurface(self,IC : int,IS : int) -> OCP.Geom.Geom_Surface: 
        """
        Returns the IS'th surface calculated on the contour IC.
        """
    @overload
    def Contains(self,E : OCP.TopoDS.TopoDS_Edge) -> int: 
        """
        gives the number of the contour containing E or 0 if E does not belong to any contour.

        gives the number of the contour containing E or 0 if E does not belong to any contour. Sets in IndexInSpine the index of E in the contour if it's found
        """
    @overload
    def Contains(self,E : OCP.TopoDS.TopoDS_Edge,IndexInSpine : int) -> int: ...
    def CurveOnFace1(self,Index : int) -> OCP.Geom.Geom_Curve: 
        """
        gives the 3d curve of SurfaceFillet(Index) on SupportFace1(Index)
        """
    def CurveOnFace2(self,Index : int) -> OCP.Geom.Geom_Curve: 
        """
        gives the 3d curve of SurfaceFillet(Index) on SupportFace2(Index)
        """
    def Done(self) -> bool: ...
    def EndSectionStatus(self) -> FilletSurf_StatusType: ...
    def FaultyContour(self,I : int) -> int: 
        """
        Returns the number of I'th contour on which the calculation has failed.
        """
    def FaultyVertex(self,IV : int) -> OCP.TopoDS.TopoDS_Vertex: 
        """
        Returns the IV'th vertex on which the calculation has failed.
        """
    def FirstParameter(self) -> float: 
        """
        gives the parameter of the fillet on the first edge.
        """
    def FirstVertex(self,IC : int) -> OCP.TopoDS.TopoDS_Vertex: 
        """
        returns the First vertex V of the contour of index IC.
        """
    def Generated(self,EouV : OCP.TopoDS.TopoDS_Shape) -> OCP.TopTools.TopTools_ListOfShape: 
        """
        Advanced function for the history
        """
    def GetBounds(self,IC : int,E : OCP.TopoDS.TopoDS_Edge,First : float,Last : float) -> bool: 
        """
        Returns in First and Last les extremities of the part of variable vector framing E, returns False if E is flagged as edge constant.
        """
    def GetFilletShape(self) -> OCP.ChFi3d.ChFi3d_FilletShape: 
        """
        Returns the type of fillet surface.
        """
    def GetLaw(self,IC : int,E : OCP.TopoDS.TopoDS_Edge) -> OCP.Law.Law_Function: 
        """
        Returns the rule of elementary evolution of the part to variable vector framing E, returns a rule zero if E is flagged as edge constant.
        """
    def HasResult(self) -> bool: 
        """
        returns True if a partial result has been calculated
        """
    @overload
    def IsConstant(self,IC : int) -> bool: 
        """
        Returns true the contour is flagged as edge constant.

        Returns true E is flagged as edge constant.
        """
    @overload
    def IsConstant(self,IC : int,E : OCP.TopoDS.TopoDS_Edge) -> bool: ...
    def IsDone(self) -> bool: 
        """
        returns True if the computation is success
        """
    def LastParameter(self) -> float: 
        """
        gives the parameter of the fillet on the last edge
        """
    def LastVertex(self,IC : int) -> OCP.TopoDS.TopoDS_Vertex: 
        """
        returns the Last vertex V of the contour of index IC.
        """
    def Length(self,IC : int) -> float: 
        """
        returns the length of the contour of index IC.
        """
    def NbComputedSurfaces(self,IC : int) -> int: 
        """
        Returns the number of surfaces calculated on the contour IC.
        """
    def NbElements(self) -> int: 
        """
        gives the number of disjoint contours on which the fillets are calculated
        """
    def NbFaultyContours(self) -> int: 
        """
        Returns the number of contours on which the calculation has failed.
        """
    def NbFaultyVertices(self) -> int: 
        """
        Returns the number of vertices on which the calculation has failed.
        """
    def NbSection(self,IndexSurf : int) -> int: ...
    def NbSurf(self,IC : int) -> int: ...
    def NbSurface(self) -> int: 
        """
        gives the number of NUBS surfaces of the Fillet.
        """
    def PCurve1OnFillet(self,Index : int) -> OCP.Geom2d.Geom2d_Curve: 
        """
        gives the PCurve associated to CurveOnFace1(Index) on the Fillet
        """
    def PCurve2OnFillet(self,Index : int) -> OCP.Geom2d.Geom2d_Curve: 
        """
        gives the PCurve associated to CurveOnSup2(Index) on the fillet
        """
    def PCurveOnFace1(self,Index : int) -> OCP.Geom2d.Geom2d_Curve: 
        """
        gives the PCurve associated to CurvOnSup1(Index) on the support face
        """
    def PCurveOnFace2(self,Index : int) -> OCP.Geom2d.Geom2d_Curve: 
        """
        gives the PCurve associated to CurveOnSup2(Index) on the support face
        """
    def Perform(self) -> None: ...
    def PerformTwoCornerbyInter(self,Index : int) -> bool: ...
    @overload
    def Radius(self,IC : int) -> float: 
        """
        Returns the vector if the contour is flagged as edge constant.

        Returns the vector if E is flagged as edge constant.
        """
    @overload
    def Radius(self,IC : int,E : OCP.TopoDS.TopoDS_Edge) -> float: ...
    def RelativeAbscissa(self,IC : int,V : OCP.TopoDS.TopoDS_Vertex) -> float: 
        """
        returns the relative abscissa([0.,1.]) of the vertex V on the contour of index IC.
        """
    def Remove(self,E : OCP.TopoDS.TopoDS_Edge) -> None: 
        """
        extracts from the list the contour containing edge E.
        """
    def Reset(self) -> None: 
        """
        Reset all results of compute and returns the algorithm in the state of the last acquisition to enable modification of contours or areas.
        """
    def ResetContour(self,IC : int) -> None: 
        """
        Reset all vectors of contour IC.
        """
    def Sect(self,IC : int,IS : int) -> OCP.ChFiDS.ChFiDS_SecHArray1: ...
    def Section(self,IndexSurf : int,IndexSec : int,Circ : OCP.Geom.Geom_TrimmedCurve) -> Any: ...
    def SetContinuity(self,InternalContinuity : OCP.GeomAbs.GeomAbs_Shape,AngularTolerance : float) -> None: ...
    def SetFilletShape(self,FShape : OCP.ChFi3d.ChFi3d_FilletShape) -> None: 
        """
        Sets the type of fillet surface.
        """
    def SetLaw(self,IC : int,E : OCP.TopoDS.TopoDS_Edge,L : OCP.Law.Law_Function) -> None: 
        """
        Sets the rule of elementary evolution of the part to variable vector framing E.
        """
    def SetParams(self,Tang : float,Tesp : float,T2d : float,TApp3d : float,TolApp2d : float,Fleche : float) -> None: ...
    @overload
    def SetRadius(self,C : OCP.Law.Law_Function,IC : int,IinC : int) -> None: 
        """
        Set the radius of the contour of index IC.

        Set a constant on edge E of the contour of index IC. Since then E is flagged as constant.

        Set a vector on vertex V of the contour of index IC.

        Set a vertex on the point of parametre U in the edge IinC of the contour of index IC
        """
    @overload
    def SetRadius(self,Radius : float,IC : int,E : OCP.TopoDS.TopoDS_Edge) -> None: ...
    @overload
    def SetRadius(self,Radius : float,IC : int,V : OCP.TopoDS.TopoDS_Vertex) -> None: ...
    @overload
    def SetRadius(self,UandR : OCP.gp.gp_XY,IC : int,IinC : int) -> None: ...
    def Shape(self) -> OCP.TopoDS.TopoDS_Shape: 
        """
        if (Isdone()) makes the result. if (!Isdone())
        """
    def Simulate(self) -> None: ...
    def SplitKPart(self,Data : OCP.ChFiDS.ChFiDS_SurfData,SetData : OCP.ChFiDS.ChFiDS_SequenceOfSurfData,Spine : OCP.ChFiDS.ChFiDS_Spine,Iedge : int,S1 : OCP.Adaptor3d.Adaptor3d_Surface,I1 : OCP.Adaptor3d.Adaptor3d_TopolTool,S2 : OCP.Adaptor3d.Adaptor3d_Surface,I2 : OCP.Adaptor3d.Adaptor3d_TopolTool,Intf : bool,Intl : bool) -> bool: 
        """
        Method, implemented in the inheritants, calculates the elements of construction of the surface (fillet or chamfer).
        """
    def StartSectionStatus(self) -> FilletSurf_StatusType: ...
    def StripeStatus(self,IC : int) -> OCP.ChFiDS.ChFiDS_ErrorStatus: 
        """
        for the stripe IC ,indication on the cause of failure WalkingFailure,TwistedSurface,Error, Ok
        """
    def SupportFace1(self,Index : int) -> OCP.TopoDS.TopoDS_Face: 
        """
        gives the first support face relative to SurfaceFillet(Index);
        """
    def SupportFace2(self,Index : int) -> OCP.TopoDS.TopoDS_Face: 
        """
        gives the second support face relative to SurfaceFillet(Index);
        """
    def SurfaceFillet(self,Index : int) -> OCP.Geom.Geom_Surface: 
        """
        gives the NUBS surface of index Index.
        """
    def TolApp3d(self,Index : int) -> float: 
        """
        gives the 3d tolerance reached during approximation of the surface of index Index
        """
    @overload
    def UnSet(self,IC : int,E : OCP.TopoDS.TopoDS_Edge) -> None: 
        """
        Extracts the flag constant and the vector of edge E.

        Extracts the vector of the vertex V.
        """
    @overload
    def UnSet(self,IC : int,V : OCP.TopoDS.TopoDS_Vertex) -> None: ...
    def Value(self,I : int) -> OCP.ChFiDS.ChFiDS_Spine: 
        """
        gives the n'th set of edges (contour) if I >NbElements()
        """
    def __init__(self,S : OCP.TopoDS.TopoDS_Shape,FShape : OCP.ChFi3d.ChFi3d_FilletShape=ChFi3d_FilletShape.ChFi3d_Polynomial,Ta : float=0.01,Tapp3d : float=0.0001,Tapp2d : float=1e-05) -> None: ...
    pass
class FilletSurf_StatusDone():
    """
    Members:

      FilletSurf_IsOk

      FilletSurf_IsNotOk

      FilletSurf_IsPartial
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    FilletSurf_IsNotOk: OCP.FilletSurf.FilletSurf_StatusDone # value = <FilletSurf_StatusDone.FilletSurf_IsNotOk: 1>
    FilletSurf_IsOk: OCP.FilletSurf.FilletSurf_StatusDone # value = <FilletSurf_StatusDone.FilletSurf_IsOk: 0>
    FilletSurf_IsPartial: OCP.FilletSurf.FilletSurf_StatusDone # value = <FilletSurf_StatusDone.FilletSurf_IsPartial: 2>
    __entries: dict # value = {'FilletSurf_IsOk': (<FilletSurf_StatusDone.FilletSurf_IsOk: 0>, None), 'FilletSurf_IsNotOk': (<FilletSurf_StatusDone.FilletSurf_IsNotOk: 1>, None), 'FilletSurf_IsPartial': (<FilletSurf_StatusDone.FilletSurf_IsPartial: 2>, None)}
    __members__: dict # value = {'FilletSurf_IsOk': <FilletSurf_StatusDone.FilletSurf_IsOk: 0>, 'FilletSurf_IsNotOk': <FilletSurf_StatusDone.FilletSurf_IsNotOk: 1>, 'FilletSurf_IsPartial': <FilletSurf_StatusDone.FilletSurf_IsPartial: 2>}
    pass
class FilletSurf_StatusType():
    """
    Members:

      FilletSurf_TwoExtremityOnEdge

      FilletSurf_OneExtremityOnEdge

      FilletSurf_NoExtremityOnEdge
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    FilletSurf_NoExtremityOnEdge: OCP.FilletSurf.FilletSurf_StatusType # value = <FilletSurf_StatusType.FilletSurf_NoExtremityOnEdge: 2>
    FilletSurf_OneExtremityOnEdge: OCP.FilletSurf.FilletSurf_StatusType # value = <FilletSurf_StatusType.FilletSurf_OneExtremityOnEdge: 1>
    FilletSurf_TwoExtremityOnEdge: OCP.FilletSurf.FilletSurf_StatusType # value = <FilletSurf_StatusType.FilletSurf_TwoExtremityOnEdge: 0>
    __entries: dict # value = {'FilletSurf_TwoExtremityOnEdge': (<FilletSurf_StatusType.FilletSurf_TwoExtremityOnEdge: 0>, None), 'FilletSurf_OneExtremityOnEdge': (<FilletSurf_StatusType.FilletSurf_OneExtremityOnEdge: 1>, None), 'FilletSurf_NoExtremityOnEdge': (<FilletSurf_StatusType.FilletSurf_NoExtremityOnEdge: 2>, None)}
    __members__: dict # value = {'FilletSurf_TwoExtremityOnEdge': <FilletSurf_StatusType.FilletSurf_TwoExtremityOnEdge: 0>, 'FilletSurf_OneExtremityOnEdge': <FilletSurf_StatusType.FilletSurf_OneExtremityOnEdge: 1>, 'FilletSurf_NoExtremityOnEdge': <FilletSurf_StatusType.FilletSurf_NoExtremityOnEdge: 2>}
    pass
FilletSurf_EdgeNotG1: OCP.FilletSurf.FilletSurf_ErrorTypeStatus # value = <FilletSurf_ErrorTypeStatus.FilletSurf_EdgeNotG1: 1>
FilletSurf_EdgeNotOnShape: OCP.FilletSurf.FilletSurf_ErrorTypeStatus # value = <FilletSurf_ErrorTypeStatus.FilletSurf_EdgeNotOnShape: 3>
FilletSurf_EmptyList: OCP.FilletSurf.FilletSurf_ErrorTypeStatus # value = <FilletSurf_ErrorTypeStatus.FilletSurf_EmptyList: 0>
FilletSurf_FacesNotG1: OCP.FilletSurf.FilletSurf_ErrorTypeStatus # value = <FilletSurf_ErrorTypeStatus.FilletSurf_FacesNotG1: 2>
FilletSurf_IsNotOk: OCP.FilletSurf.FilletSurf_StatusDone # value = <FilletSurf_StatusDone.FilletSurf_IsNotOk: 1>
FilletSurf_IsOk: OCP.FilletSurf.FilletSurf_StatusDone # value = <FilletSurf_StatusDone.FilletSurf_IsOk: 0>
FilletSurf_IsPartial: OCP.FilletSurf.FilletSurf_StatusDone # value = <FilletSurf_StatusDone.FilletSurf_IsPartial: 2>
FilletSurf_NoExtremityOnEdge: OCP.FilletSurf.FilletSurf_StatusType # value = <FilletSurf_StatusType.FilletSurf_NoExtremityOnEdge: 2>
FilletSurf_NotSharpEdge: OCP.FilletSurf.FilletSurf_ErrorTypeStatus # value = <FilletSurf_ErrorTypeStatus.FilletSurf_NotSharpEdge: 4>
FilletSurf_OneExtremityOnEdge: OCP.FilletSurf.FilletSurf_StatusType # value = <FilletSurf_StatusType.FilletSurf_OneExtremityOnEdge: 1>
FilletSurf_PbFilletCompute: OCP.FilletSurf.FilletSurf_ErrorTypeStatus # value = <FilletSurf_ErrorTypeStatus.FilletSurf_PbFilletCompute: 5>
FilletSurf_TwoExtremityOnEdge: OCP.FilletSurf.FilletSurf_StatusType # value = <FilletSurf_StatusType.FilletSurf_TwoExtremityOnEdge: 0>



import OCP.GProp
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.TColStd
import OCP.gp
import OCP.TColgp
__all__  = [
"GProp",
"GProp_GProps",
"GProp_EquaType",
"GProp_CelGProps",
"GProp_PEquation",
"GProp_PGProps",
"GProp_PrincipalProps",
"GProp_SelGProps",
"GProp_UndefinedAxis",
"GProp_ValueType",
"GProp_VelGProps",
"GProp_CenterMassX",
"GProp_CenterMassY",
"GProp_CenterMassZ",
"GProp_InertiaXX",
"GProp_InertiaXY",
"GProp_InertiaXZ",
"GProp_InertiaYY",
"GProp_InertiaYZ",
"GProp_InertiaZZ",
"GProp_Line",
"GProp_Mass",
"GProp_None",
"GProp_Plane",
"GProp_Point",
"GProp_Space",
"GProp_Unknown"
]
class GProp():
    """
    This package defines algorithms to compute the global properties of a set of points, a curve, a surface, a solid (non infinite region of space delimited with geometric entities), a compound geometric system (heterogeneous composition of the previous entities).
    """
    @staticmethod
    def HOperator_s(G : OCP.gp.gp_Pnt,Q : OCP.gp.gp_Pnt,Mass : float,Operator : OCP.gp.gp_Mat) -> None: 
        """
        methods of package Computes the matrix Operator, referred to as the "Huyghens Operator" of a geometric system at the point Q of the space, using the following data : - Mass, i.e. the mass of the system, - G, the center of mass of the system. The "Huyghens Operator" is used to compute Inertia/Q, the matrix of inertia of the system at the point Q using Huyghens' theorem : Inertia/Q = Inertia/G + HOperator (Q, G, Mass) where Inertia/G is the matrix of inertia of the system relative to its center of mass as returned by the function MatrixOfInertia on any GProp_GProps object.
        """
    def __init__(self) -> None: ...
    pass
class GProp_GProps():
    """
    Implements a general mechanism to compute the global properties of a "compound geometric system" in 3d space by composition of the global properties of "elementary geometric entities" such as (curve, surface, solid, set of points). It is possible to compose the properties of several "compound geometric systems" too.
    """
    def Add(self,Item : GProp_GProps,Density : float=1.0) -> None: 
        """
        Either - initializes the global properties retained by this framework from those retained by the framework Item, or - brings together the global properties still retained by this framework with those retained by the framework Item. The value Density, which is 1.0 by default, is used as the density of the system analysed by Item. Sometimes the density will have already been given at the time of construction of the framework Item. This may be the case for example, if Item is a GProp_PGProps framework built to compute the global properties of a set of points ; or another GProp_GProps object which already retains composite global properties. In these cases the real density was perhaps already taken into account at the time of construction of Item. Note that this is not checked: if the density of parts of the system is taken into account two or more times, results of the computation will be false. Notes : - The point relative to which the inertia of Item is computed (i.e. the reference point of Item) may be different from the reference point in this framework. Huygens' theorem is applied automatically to transfer inertia values to the reference point in this framework. - The function Add is used once per component of the system. After that, you use the interrogation functions available to access values computed for the system. - The system whose global properties are already brought together by this framework is referred to as the current system. However, the current system is not retained by this framework, which maintains only its global properties. Exceptions Standard_DomainError if Density is less than or equal to gp::Resolution().
        """
    def CentreOfMass(self) -> OCP.gp.gp_Pnt: 
        """
        Returns the center of mass of the current system. If the gravitational field is uniform, it is the center of gravity. The coordinates returned for the center of mass are expressed in the absolute Cartesian coordinate system.
        """
    def Mass(self) -> float: 
        """
        Returns the mass of the current system. If no density is attached to the components of the current system the returned value corresponds to : - the total length of the edges of the current system if this framework retains only linear properties, as is the case for example, when using only the LinearProperties function to combine properties of lines from shapes, or - the total area of the faces of the current system if this framework retains only surface properties, as is the case for example, when using only the SurfaceProperties function to combine properties of surfaces from shapes, or - the total volume of the solids of the current system if this framework retains only volume properties, as is the case for example, when using only the VolumeProperties function to combine properties of volumes from solids. Warning A length, an area, or a volume is computed in the current data unit system. The mass of a single object is obtained by multiplying its length, its area or its volume by the given density. You must be consistent with respect to the units used.
        """
    def MatrixOfInertia(self) -> OCP.gp.gp_Mat: 
        """
        returns the matrix of inertia. It is a symmetrical matrix. The coefficients of the matrix are the quadratic moments of inertia.
        """
    def MomentOfInertia(self,A : OCP.gp.gp_Ax1) -> float: 
        """
        computes the moment of inertia of the material system about the axis A.
        """
    def PrincipalProperties(self) -> GProp_PrincipalProps: 
        """
        Computes the principal properties of inertia of the current system. There is always a set of axes for which the products of inertia of a geometric system are equal to 0; i.e. the matrix of inertia of the system is diagonal. These axes are the principal axes of inertia. Their origin is coincident with the center of mass of the system. The associated moments are called the principal moments of inertia. This function computes the eigen values and the eigen vectors of the matrix of inertia of the system. Results are stored by using a presentation framework of principal properties of inertia (GProp_PrincipalProps object) which may be queried to access the value sought.
        """
    def RadiusOfGyration(self,A : OCP.gp.gp_Ax1) -> float: 
        """
        Returns the radius of gyration of the current system about the axis A.
        """
    def StaticMoments(self) -> tuple[float, float, float]: 
        """
        Returns Ix, Iy, Iz, the static moments of inertia of the current system; i.e. the moments of inertia about the three axes of the Cartesian coordinate system.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,SystemLocation : OCP.gp.gp_Pnt) -> None: ...
    pass
class GProp_EquaType():
    """
    Members:

      GProp_Plane

      GProp_Line

      GProp_Point

      GProp_Space

      GProp_None
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    GProp_Line: OCP.GProp.GProp_EquaType # value = <GProp_EquaType.GProp_Line: 1>
    GProp_None: OCP.GProp.GProp_EquaType # value = <GProp_EquaType.GProp_None: 4>
    GProp_Plane: OCP.GProp.GProp_EquaType # value = <GProp_EquaType.GProp_Plane: 0>
    GProp_Point: OCP.GProp.GProp_EquaType # value = <GProp_EquaType.GProp_Point: 2>
    GProp_Space: OCP.GProp.GProp_EquaType # value = <GProp_EquaType.GProp_Space: 3>
    __entries: dict # value = {'GProp_Plane': (<GProp_EquaType.GProp_Plane: 0>, None), 'GProp_Line': (<GProp_EquaType.GProp_Line: 1>, None), 'GProp_Point': (<GProp_EquaType.GProp_Point: 2>, None), 'GProp_Space': (<GProp_EquaType.GProp_Space: 3>, None), 'GProp_None': (<GProp_EquaType.GProp_None: 4>, None)}
    __members__: dict # value = {'GProp_Plane': <GProp_EquaType.GProp_Plane: 0>, 'GProp_Line': <GProp_EquaType.GProp_Line: 1>, 'GProp_Point': <GProp_EquaType.GProp_Point: 2>, 'GProp_Space': <GProp_EquaType.GProp_Space: 3>, 'GProp_None': <GProp_EquaType.GProp_None: 4>}
    pass
class GProp_CelGProps(GProp_GProps):
    """
    Computes the global properties of bounded curves in 3D space. It can be an elementary curve from package gp such as Lin, Circ, Elips, Parab .
    """
    def Add(self,Item : GProp_GProps,Density : float=1.0) -> None: 
        """
        Either - initializes the global properties retained by this framework from those retained by the framework Item, or - brings together the global properties still retained by this framework with those retained by the framework Item. The value Density, which is 1.0 by default, is used as the density of the system analysed by Item. Sometimes the density will have already been given at the time of construction of the framework Item. This may be the case for example, if Item is a GProp_PGProps framework built to compute the global properties of a set of points ; or another GProp_GProps object which already retains composite global properties. In these cases the real density was perhaps already taken into account at the time of construction of Item. Note that this is not checked: if the density of parts of the system is taken into account two or more times, results of the computation will be false. Notes : - The point relative to which the inertia of Item is computed (i.e. the reference point of Item) may be different from the reference point in this framework. Huygens' theorem is applied automatically to transfer inertia values to the reference point in this framework. - The function Add is used once per component of the system. After that, you use the interrogation functions available to access values computed for the system. - The system whose global properties are already brought together by this framework is referred to as the current system. However, the current system is not retained by this framework, which maintains only its global properties. Exceptions Standard_DomainError if Density is less than or equal to gp::Resolution().
        """
    def CentreOfMass(self) -> OCP.gp.gp_Pnt: 
        """
        Returns the center of mass of the current system. If the gravitational field is uniform, it is the center of gravity. The coordinates returned for the center of mass are expressed in the absolute Cartesian coordinate system.
        """
    def Mass(self) -> float: 
        """
        Returns the mass of the current system. If no density is attached to the components of the current system the returned value corresponds to : - the total length of the edges of the current system if this framework retains only linear properties, as is the case for example, when using only the LinearProperties function to combine properties of lines from shapes, or - the total area of the faces of the current system if this framework retains only surface properties, as is the case for example, when using only the SurfaceProperties function to combine properties of surfaces from shapes, or - the total volume of the solids of the current system if this framework retains only volume properties, as is the case for example, when using only the VolumeProperties function to combine properties of volumes from solids. Warning A length, an area, or a volume is computed in the current data unit system. The mass of a single object is obtained by multiplying its length, its area or its volume by the given density. You must be consistent with respect to the units used.
        """
    def MatrixOfInertia(self) -> OCP.gp.gp_Mat: 
        """
        returns the matrix of inertia. It is a symmetrical matrix. The coefficients of the matrix are the quadratic moments of inertia.
        """
    def MomentOfInertia(self,A : OCP.gp.gp_Ax1) -> float: 
        """
        computes the moment of inertia of the material system about the axis A.
        """
    @overload
    def Perform(self,C : OCP.gp.gp_Circ,U1 : float,U2 : float) -> None: ...
    @overload
    def Perform(self,C : OCP.gp.gp_Lin,U1 : float,U2 : float) -> None: ...
    def PrincipalProperties(self) -> GProp_PrincipalProps: 
        """
        Computes the principal properties of inertia of the current system. There is always a set of axes for which the products of inertia of a geometric system are equal to 0; i.e. the matrix of inertia of the system is diagonal. These axes are the principal axes of inertia. Their origin is coincident with the center of mass of the system. The associated moments are called the principal moments of inertia. This function computes the eigen values and the eigen vectors of the matrix of inertia of the system. Results are stored by using a presentation framework of principal properties of inertia (GProp_PrincipalProps object) which may be queried to access the value sought.
        """
    def RadiusOfGyration(self,A : OCP.gp.gp_Ax1) -> float: 
        """
        Returns the radius of gyration of the current system about the axis A.
        """
    def SetLocation(self,CLocation : OCP.gp.gp_Pnt) -> None: ...
    def StaticMoments(self) -> tuple[float, float, float]: 
        """
        Returns Ix, Iy, Iz, the static moments of inertia of the current system; i.e. the moments of inertia about the three axes of the Cartesian coordinate system.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,C : OCP.gp.gp_Circ,CLocation : OCP.gp.gp_Pnt) -> None: ...
    @overload
    def __init__(self,C : OCP.gp.gp_Circ,U1 : float,U2 : float,CLocation : OCP.gp.gp_Pnt) -> None: ...
    @overload
    def __init__(self,C : OCP.gp.gp_Lin,U1 : float,U2 : float,CLocation : OCP.gp.gp_Pnt) -> None: ...
    pass
class GProp_PEquation():
    """
    A framework to analyze a collection - or cloud - of points and to verify if they are coincident, collinear or coplanar within a given precision. If so, it also computes the mean point, the mean line or the mean plane of the points. If not, it computes the minimal box which includes all the points.
    """
    def Box(self,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec,V2 : OCP.gp.gp_Vec,V3 : OCP.gp.gp_Vec) -> None: 
        """
        Returns the definition of the smallest box which contains all the points analyzed by this framework if, according to the given precision value, the points are considered to be neither coincident, nor collinear and nor coplanar. This box is centered on the barycenter P of the collection of points. Its sides are parallel to the three vectors V1, V2 and V3, the length of which is the length of the box in the corresponding direction. Note: Vectors V1, V2 and V3 are parallel to the three axes of principal inertia of the system composed of the collection of points where each point is of equal mass. Exceptions Standard_NoSuchObject if, according to the given precision, the points analyzed by this framework are considered to be coincident, collinear or coplanar.
        """
    def IsLinear(self) -> bool: 
        """
        Returns true if, according to the given tolerance, the points analyzed by this framework are colinear. Use the function Line to access the computed result.
        """
    def IsPlanar(self) -> bool: 
        """
        Returns true if, according to the given tolerance, the points analyzed by this framework are coplanar. Use the function Plane to access the computed result.
        """
    def IsPoint(self) -> bool: 
        """
        Returns true if, according to the given tolerance, the points analyzed by this framework are coincident. Use the function Point to access the computed result.
        """
    def IsSpace(self) -> bool: 
        """
        Returns true if, according to the given tolerance value, the points analyzed by this framework are neither coincident, nor collinear, nor coplanar. Use the function Box to query the smallest box that includes the collection of points.
        """
    def Line(self) -> OCP.gp.gp_Lin: 
        """
        Returns the mean line passing near all the points analyzed by this framework if, according to the given precision value, the points are considered to be collinear. Exceptions Standard_NoSuchObject if, according to the given precision, the points analyzed by this framework are considered to be: - coincident, or - not collinear.
        """
    def Plane(self) -> OCP.gp.gp_Pln: 
        """
        Returns the mean plane passing near all the points analyzed by this framework if, according to the given precision, the points are considered to be coplanar. Exceptions Standard_NoSuchObject if, according to the given precision value, the points analyzed by this framework are considered to be: - coincident, or - collinear, or - not coplanar.
        """
    def Point(self) -> OCP.gp.gp_Pnt: 
        """
        Returns the mean point of all the points analyzed by this framework if, according to the given precision, the points are considered to be coincident. Exceptions Standard_NoSuchObject if, according to the given precision, the points analyzed by this framework are not considered to be coincident.
        """
    def __init__(self,Pnts : OCP.TColgp.TColgp_Array1OfPnt,Tol : float) -> None: ...
    pass
class GProp_PGProps(GProp_GProps):
    """
    A framework for computing the global properties of a set of points. A point mass is attached to each point. The global mass of the system is the sum of each individual mass. By default, the point mass is equal to 1 and the mass of a system composed of N points is equal to N. Warning A framework of this sort provides functions to handle sets of points easily. But, like any GProp_GProps object, by using the Add function, it can theoretically bring together the computed global properties and those of a system more complex than a set of points . The mass of each point and the density of each component of the composed system must be coherent. Note that this coherence cannot be checked. Nonetheless, you are advised to restrict your use of a GProp_PGProps object to a set of points and to create a GProp_GProps object in order to bring together global properties of different systems.
    """
    def Add(self,Item : GProp_GProps,Density : float=1.0) -> None: 
        """
        Either - initializes the global properties retained by this framework from those retained by the framework Item, or - brings together the global properties still retained by this framework with those retained by the framework Item. The value Density, which is 1.0 by default, is used as the density of the system analysed by Item. Sometimes the density will have already been given at the time of construction of the framework Item. This may be the case for example, if Item is a GProp_PGProps framework built to compute the global properties of a set of points ; or another GProp_GProps object which already retains composite global properties. In these cases the real density was perhaps already taken into account at the time of construction of Item. Note that this is not checked: if the density of parts of the system is taken into account two or more times, results of the computation will be false. Notes : - The point relative to which the inertia of Item is computed (i.e. the reference point of Item) may be different from the reference point in this framework. Huygens' theorem is applied automatically to transfer inertia values to the reference point in this framework. - The function Add is used once per component of the system. After that, you use the interrogation functions available to access values computed for the system. - The system whose global properties are already brought together by this framework is referred to as the current system. However, the current system is not retained by this framework, which maintains only its global properties. Exceptions Standard_DomainError if Density is less than or equal to gp::Resolution().
        """
    @overload
    def AddPoint(self,P : OCP.gp.gp_Pnt) -> None: 
        """
        Brings together the global properties already retained by this framework with those induced by the point Pnt. Pnt may be the first point of the current system. A point mass is attached to the point Pnt, it is either equal to 1. or to Density.

        Adds a new point P with its density in the system of points Exceptions Standard_DomainError if the mass value Density is less than gp::Resolution().
        """
    @overload
    def AddPoint(self,P : OCP.gp.gp_Pnt,Density : float) -> None: ...
    @staticmethod
    @overload
    def Barycentre_s(Pnts : OCP.TColgp.TColgp_Array1OfPnt) -> OCP.gp.gp_Pnt: 
        """
        Computes the barycentre of a set of points. The density of the points is defaulted to 1.

        Computes the barycentre of a set of points. The density of the points is defaulted to 1.

        Computes the barycentre of a set of points. A density is associated with each point.

        Computes the barycentre of a set of points. A density is associated with each point.
        """
    @staticmethod
    @overload
    def Barycentre_s(Pnts : OCP.TColgp.TColgp_Array2OfPnt) -> OCP.gp.gp_Pnt: ...
    @staticmethod
    @overload
    def Barycentre_s(Pnts : OCP.TColgp.TColgp_Array1OfPnt,Density : OCP.TColStd.TColStd_Array1OfReal,G : OCP.gp.gp_Pnt) -> tuple[float]: ...
    @staticmethod
    @overload
    def Barycentre_s(Pnts : OCP.TColgp.TColgp_Array2OfPnt,Density : OCP.TColStd.TColStd_Array2OfReal,G : OCP.gp.gp_Pnt) -> tuple[float]: ...
    def CentreOfMass(self) -> OCP.gp.gp_Pnt: 
        """
        Returns the center of mass of the current system. If the gravitational field is uniform, it is the center of gravity. The coordinates returned for the center of mass are expressed in the absolute Cartesian coordinate system.
        """
    def Mass(self) -> float: 
        """
        Returns the mass of the current system. If no density is attached to the components of the current system the returned value corresponds to : - the total length of the edges of the current system if this framework retains only linear properties, as is the case for example, when using only the LinearProperties function to combine properties of lines from shapes, or - the total area of the faces of the current system if this framework retains only surface properties, as is the case for example, when using only the SurfaceProperties function to combine properties of surfaces from shapes, or - the total volume of the solids of the current system if this framework retains only volume properties, as is the case for example, when using only the VolumeProperties function to combine properties of volumes from solids. Warning A length, an area, or a volume is computed in the current data unit system. The mass of a single object is obtained by multiplying its length, its area or its volume by the given density. You must be consistent with respect to the units used.
        """
    def MatrixOfInertia(self) -> OCP.gp.gp_Mat: 
        """
        returns the matrix of inertia. It is a symmetrical matrix. The coefficients of the matrix are the quadratic moments of inertia.
        """
    def MomentOfInertia(self,A : OCP.gp.gp_Ax1) -> float: 
        """
        computes the moment of inertia of the material system about the axis A.
        """
    def PrincipalProperties(self) -> GProp_PrincipalProps: 
        """
        Computes the principal properties of inertia of the current system. There is always a set of axes for which the products of inertia of a geometric system are equal to 0; i.e. the matrix of inertia of the system is diagonal. These axes are the principal axes of inertia. Their origin is coincident with the center of mass of the system. The associated moments are called the principal moments of inertia. This function computes the eigen values and the eigen vectors of the matrix of inertia of the system. Results are stored by using a presentation framework of principal properties of inertia (GProp_PrincipalProps object) which may be queried to access the value sought.
        """
    def RadiusOfGyration(self,A : OCP.gp.gp_Ax1) -> float: 
        """
        Returns the radius of gyration of the current system about the axis A.
        """
    def StaticMoments(self) -> tuple[float, float, float]: 
        """
        Returns Ix, Iy, Iz, the static moments of inertia of the current system; i.e. the moments of inertia about the three axes of the Cartesian coordinate system.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,Pnts : OCP.TColgp.TColgp_Array1OfPnt) -> None: ...
    @overload
    def __init__(self,Pnts : OCP.TColgp.TColgp_Array2OfPnt) -> None: ...
    @overload
    def __init__(self,Pnts : OCP.TColgp.TColgp_Array1OfPnt,Density : OCP.TColStd.TColStd_Array1OfReal) -> None: ...
    @overload
    def __init__(self,Pnts : OCP.TColgp.TColgp_Array2OfPnt,Density : OCP.TColStd.TColStd_Array2OfReal) -> None: ...
    pass
class GProp_PrincipalProps():
    """
    A framework to present the principal properties of inertia of a system of which global properties are computed by a GProp_GProps object. There is always a set of axes for which the products of inertia of a geometric system are equal to 0; i.e. the matrix of inertia of the system is diagonal. These axes are the principal axes of inertia. Their origin is coincident with the center of mass of the system. The associated moments are called the principal moments of inertia. This sort of presentation object is created, filled and returned by the function PrincipalProperties for any GProp_GProps object, and can be queried to access the result. Note: The system whose principal properties of inertia are returned by this framework is referred to as the current system. The current system, however, is retained neither by this presentation framework nor by the GProp_GProps object which activates it.
    """
    def FirstAxisOfInertia(self) -> OCP.gp.gp_Vec: 
        """
        returns the first axis of inertia.
        """
    @overload
    def HasSymmetryAxis(self) -> bool: 
        """
        returns true if the geometric system has an axis of symmetry. For comparing moments relative tolerance 1.e-10 is used. Usually it is enough for objects, restricted by faces with analytical geometry.

        returns true if the geometric system has an axis of symmetry. aTol is relative tolerance for checking equality of moments If aTol == 0, relative tolerance is ~ 1.e-16 (Epsilon(I))
        """
    @overload
    def HasSymmetryAxis(self,aTol : float) -> bool: ...
    @overload
    def HasSymmetryPoint(self) -> bool: 
        """
        returns true if the geometric system has a point of symmetry. For comparing moments relative tolerance 1.e-10 is used. Usually it is enough for objects, restricted by faces with analytical geometry.

        returns true if the geometric system has a point of symmetry. aTol is relative tolerance for checking equality of moments If aTol == 0, relative tolerance is ~ 1.e-16 (Epsilon(I))
        """
    @overload
    def HasSymmetryPoint(self,aTol : float) -> bool: ...
    def Moments(self) -> tuple[float, float, float]: 
        """
        Ixx, Iyy and Izz return the principal moments of inertia in the current system. Notes : - If the current system has an axis of symmetry, two of the three values Ixx, Iyy and Izz are equal. They indicate which eigen vectors define an infinity of axes of principal inertia. - If the current system has a center of symmetry, Ixx, Iyy and Izz are equal.
        """
    def RadiusOfGyration(self) -> tuple[float, float, float]: 
        """
        Returns the principal radii of gyration Rxx, Ryy and Rzz are the radii of gyration of the current system about its three principal axes of inertia. Note that: - If the current system has an axis of symmetry, two of the three values Rxx, Ryy and Rzz are equal. - If the current system has a center of symmetry, Rxx, Ryy and Rzz are equal.
        """
    def SecondAxisOfInertia(self) -> OCP.gp.gp_Vec: 
        """
        returns the second axis of inertia.
        """
    def ThirdAxisOfInertia(self) -> OCP.gp.gp_Vec: 
        """
        returns the third axis of inertia. This and the above functions return the first, second or third eigen vector of the matrix of inertia of the current system. The first, second and third principal axis of inertia pass through the center of mass of the current system. They are respectively parallel to these three eigen vectors. Note that: - If the current system has an axis of symmetry, any axis is an axis of principal inertia if it passes through the center of mass of the system, and runs parallel to a linear combination of the two eigen vectors of the matrix of inertia, corresponding to the two eigen values which are equal. If the current system has a center of symmetry, any axis passing through the center of mass of the system is an axis of principal inertia. Use the functions HasSymmetryAxis and HasSymmetryPoint to check these particular cases, where the returned eigen vectors define an infinity of principal axis of inertia. - The Moments function can be used to know which of the three eigen vectors corresponds to the two eigen values which are equal.
        """
    def __init__(self) -> None: ...
    pass
class GProp_SelGProps(GProp_GProps):
    """
    Computes the global properties of a bounded elementary surface in 3d (surface of the gp package)
    """
    def Add(self,Item : GProp_GProps,Density : float=1.0) -> None: 
        """
        Either - initializes the global properties retained by this framework from those retained by the framework Item, or - brings together the global properties still retained by this framework with those retained by the framework Item. The value Density, which is 1.0 by default, is used as the density of the system analysed by Item. Sometimes the density will have already been given at the time of construction of the framework Item. This may be the case for example, if Item is a GProp_PGProps framework built to compute the global properties of a set of points ; or another GProp_GProps object which already retains composite global properties. In these cases the real density was perhaps already taken into account at the time of construction of Item. Note that this is not checked: if the density of parts of the system is taken into account two or more times, results of the computation will be false. Notes : - The point relative to which the inertia of Item is computed (i.e. the reference point of Item) may be different from the reference point in this framework. Huygens' theorem is applied automatically to transfer inertia values to the reference point in this framework. - The function Add is used once per component of the system. After that, you use the interrogation functions available to access values computed for the system. - The system whose global properties are already brought together by this framework is referred to as the current system. However, the current system is not retained by this framework, which maintains only its global properties. Exceptions Standard_DomainError if Density is less than or equal to gp::Resolution().
        """
    def CentreOfMass(self) -> OCP.gp.gp_Pnt: 
        """
        Returns the center of mass of the current system. If the gravitational field is uniform, it is the center of gravity. The coordinates returned for the center of mass are expressed in the absolute Cartesian coordinate system.
        """
    def Mass(self) -> float: 
        """
        Returns the mass of the current system. If no density is attached to the components of the current system the returned value corresponds to : - the total length of the edges of the current system if this framework retains only linear properties, as is the case for example, when using only the LinearProperties function to combine properties of lines from shapes, or - the total area of the faces of the current system if this framework retains only surface properties, as is the case for example, when using only the SurfaceProperties function to combine properties of surfaces from shapes, or - the total volume of the solids of the current system if this framework retains only volume properties, as is the case for example, when using only the VolumeProperties function to combine properties of volumes from solids. Warning A length, an area, or a volume is computed in the current data unit system. The mass of a single object is obtained by multiplying its length, its area or its volume by the given density. You must be consistent with respect to the units used.
        """
    def MatrixOfInertia(self) -> OCP.gp.gp_Mat: 
        """
        returns the matrix of inertia. It is a symmetrical matrix. The coefficients of the matrix are the quadratic moments of inertia.
        """
    def MomentOfInertia(self,A : OCP.gp.gp_Ax1) -> float: 
        """
        computes the moment of inertia of the material system about the axis A.
        """
    @overload
    def Perform(self,S : OCP.gp.gp_Cylinder,Alpha1 : float,Alpha2 : float,Z1 : float,Z2 : float) -> None: ...
    @overload
    def Perform(self,S : OCP.gp.gp_Cone,Alpha1 : float,Alpha2 : float,Z1 : float,Z2 : float) -> None: ...
    @overload
    def Perform(self,S : OCP.gp.gp_Sphere,Teta1 : float,Teta2 : float,Alpha1 : float,Alpha2 : float) -> None: ...
    @overload
    def Perform(self,S : OCP.gp.gp_Torus,Teta1 : float,Teta2 : float,Alpha1 : float,Alpha2 : float) -> None: ...
    def PrincipalProperties(self) -> GProp_PrincipalProps: 
        """
        Computes the principal properties of inertia of the current system. There is always a set of axes for which the products of inertia of a geometric system are equal to 0; i.e. the matrix of inertia of the system is diagonal. These axes are the principal axes of inertia. Their origin is coincident with the center of mass of the system. The associated moments are called the principal moments of inertia. This function computes the eigen values and the eigen vectors of the matrix of inertia of the system. Results are stored by using a presentation framework of principal properties of inertia (GProp_PrincipalProps object) which may be queried to access the value sought.
        """
    def RadiusOfGyration(self,A : OCP.gp.gp_Ax1) -> float: 
        """
        Returns the radius of gyration of the current system about the axis A.
        """
    def SetLocation(self,SLocation : OCP.gp.gp_Pnt) -> None: ...
    def StaticMoments(self) -> tuple[float, float, float]: 
        """
        Returns Ix, Iy, Iz, the static moments of inertia of the current system; i.e. the moments of inertia about the three axes of the Cartesian coordinate system.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,S : OCP.gp.gp_Cylinder,Alpha1 : float,Alpha2 : float,Z1 : float,Z2 : float,SLocation : OCP.gp.gp_Pnt) -> None: ...
    @overload
    def __init__(self,S : OCP.gp.gp_Cone,Alpha1 : float,Alpha2 : float,Z1 : float,Z2 : float,SLocation : OCP.gp.gp_Pnt) -> None: ...
    @overload
    def __init__(self,S : OCP.gp.gp_Sphere,Teta1 : float,Teta2 : float,Alpha1 : float,Alpha2 : float,SLocation : OCP.gp.gp_Pnt) -> None: ...
    @overload
    def __init__(self,S : OCP.gp.gp_Torus,Teta1 : float,Teta2 : float,Alpha1 : float,Alpha2 : float,SLocation : OCP.gp.gp_Pnt) -> None: ...
    pass
class GProp_UndefinedAxis(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.GProp', '__weakref__': <attribute '__weakref__' of 'GProp_UndefinedAxis' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'GProp_UndefinedAxis' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass
class GProp_ValueType():
    """
    Algorithms:

    Members:

      GProp_Mass

      GProp_CenterMassX

      GProp_CenterMassY

      GProp_CenterMassZ

      GProp_InertiaXX

      GProp_InertiaYY

      GProp_InertiaZZ

      GProp_InertiaXY

      GProp_InertiaXZ

      GProp_InertiaYZ

      GProp_Unknown
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    GProp_CenterMassX: OCP.GProp.GProp_ValueType # value = <GProp_ValueType.GProp_CenterMassX: 1>
    GProp_CenterMassY: OCP.GProp.GProp_ValueType # value = <GProp_ValueType.GProp_CenterMassY: 2>
    GProp_CenterMassZ: OCP.GProp.GProp_ValueType # value = <GProp_ValueType.GProp_CenterMassZ: 3>
    GProp_InertiaXX: OCP.GProp.GProp_ValueType # value = <GProp_ValueType.GProp_InertiaXX: 4>
    GProp_InertiaXY: OCP.GProp.GProp_ValueType # value = <GProp_ValueType.GProp_InertiaXY: 7>
    GProp_InertiaXZ: OCP.GProp.GProp_ValueType # value = <GProp_ValueType.GProp_InertiaXZ: 8>
    GProp_InertiaYY: OCP.GProp.GProp_ValueType # value = <GProp_ValueType.GProp_InertiaYY: 5>
    GProp_InertiaYZ: OCP.GProp.GProp_ValueType # value = <GProp_ValueType.GProp_InertiaYZ: 9>
    GProp_InertiaZZ: OCP.GProp.GProp_ValueType # value = <GProp_ValueType.GProp_InertiaZZ: 6>
    GProp_Mass: OCP.GProp.GProp_ValueType # value = <GProp_ValueType.GProp_Mass: 0>
    GProp_Unknown: OCP.GProp.GProp_ValueType # value = <GProp_ValueType.GProp_Unknown: 10>
    __entries: dict # value = {'GProp_Mass': (<GProp_ValueType.GProp_Mass: 0>, None), 'GProp_CenterMassX': (<GProp_ValueType.GProp_CenterMassX: 1>, None), 'GProp_CenterMassY': (<GProp_ValueType.GProp_CenterMassY: 2>, None), 'GProp_CenterMassZ': (<GProp_ValueType.GProp_CenterMassZ: 3>, None), 'GProp_InertiaXX': (<GProp_ValueType.GProp_InertiaXX: 4>, None), 'GProp_InertiaYY': (<GProp_ValueType.GProp_InertiaYY: 5>, None), 'GProp_InertiaZZ': (<GProp_ValueType.GProp_InertiaZZ: 6>, None), 'GProp_InertiaXY': (<GProp_ValueType.GProp_InertiaXY: 7>, None), 'GProp_InertiaXZ': (<GProp_ValueType.GProp_InertiaXZ: 8>, None), 'GProp_InertiaYZ': (<GProp_ValueType.GProp_InertiaYZ: 9>, None), 'GProp_Unknown': (<GProp_ValueType.GProp_Unknown: 10>, None)}
    __members__: dict # value = {'GProp_Mass': <GProp_ValueType.GProp_Mass: 0>, 'GProp_CenterMassX': <GProp_ValueType.GProp_CenterMassX: 1>, 'GProp_CenterMassY': <GProp_ValueType.GProp_CenterMassY: 2>, 'GProp_CenterMassZ': <GProp_ValueType.GProp_CenterMassZ: 3>, 'GProp_InertiaXX': <GProp_ValueType.GProp_InertiaXX: 4>, 'GProp_InertiaYY': <GProp_ValueType.GProp_InertiaYY: 5>, 'GProp_InertiaZZ': <GProp_ValueType.GProp_InertiaZZ: 6>, 'GProp_InertiaXY': <GProp_ValueType.GProp_InertiaXY: 7>, 'GProp_InertiaXZ': <GProp_ValueType.GProp_InertiaXZ: 8>, 'GProp_InertiaYZ': <GProp_ValueType.GProp_InertiaYZ: 9>, 'GProp_Unknown': <GProp_ValueType.GProp_Unknown: 10>}
    pass
class GProp_VelGProps(GProp_GProps):
    """
    Computes the global properties and the volume of a geometric solid (3D closed region of space) The solid can be elementary(definition in the gp package)
    """
    def Add(self,Item : GProp_GProps,Density : float=1.0) -> None: 
        """
        Either - initializes the global properties retained by this framework from those retained by the framework Item, or - brings together the global properties still retained by this framework with those retained by the framework Item. The value Density, which is 1.0 by default, is used as the density of the system analysed by Item. Sometimes the density will have already been given at the time of construction of the framework Item. This may be the case for example, if Item is a GProp_PGProps framework built to compute the global properties of a set of points ; or another GProp_GProps object which already retains composite global properties. In these cases the real density was perhaps already taken into account at the time of construction of Item. Note that this is not checked: if the density of parts of the system is taken into account two or more times, results of the computation will be false. Notes : - The point relative to which the inertia of Item is computed (i.e. the reference point of Item) may be different from the reference point in this framework. Huygens' theorem is applied automatically to transfer inertia values to the reference point in this framework. - The function Add is used once per component of the system. After that, you use the interrogation functions available to access values computed for the system. - The system whose global properties are already brought together by this framework is referred to as the current system. However, the current system is not retained by this framework, which maintains only its global properties. Exceptions Standard_DomainError if Density is less than or equal to gp::Resolution().
        """
    def CentreOfMass(self) -> OCP.gp.gp_Pnt: 
        """
        Returns the center of mass of the current system. If the gravitational field is uniform, it is the center of gravity. The coordinates returned for the center of mass are expressed in the absolute Cartesian coordinate system.
        """
    def Mass(self) -> float: 
        """
        Returns the mass of the current system. If no density is attached to the components of the current system the returned value corresponds to : - the total length of the edges of the current system if this framework retains only linear properties, as is the case for example, when using only the LinearProperties function to combine properties of lines from shapes, or - the total area of the faces of the current system if this framework retains only surface properties, as is the case for example, when using only the SurfaceProperties function to combine properties of surfaces from shapes, or - the total volume of the solids of the current system if this framework retains only volume properties, as is the case for example, when using only the VolumeProperties function to combine properties of volumes from solids. Warning A length, an area, or a volume is computed in the current data unit system. The mass of a single object is obtained by multiplying its length, its area or its volume by the given density. You must be consistent with respect to the units used.
        """
    def MatrixOfInertia(self) -> OCP.gp.gp_Mat: 
        """
        returns the matrix of inertia. It is a symmetrical matrix. The coefficients of the matrix are the quadratic moments of inertia.
        """
    def MomentOfInertia(self,A : OCP.gp.gp_Ax1) -> float: 
        """
        computes the moment of inertia of the material system about the axis A.
        """
    @overload
    def Perform(self,S : OCP.gp.gp_Cylinder,Alpha1 : float,Alpha2 : float,Z1 : float,Z2 : float) -> None: ...
    @overload
    def Perform(self,S : OCP.gp.gp_Cone,Alpha1 : float,Alpha2 : float,Z1 : float,Z2 : float) -> None: ...
    @overload
    def Perform(self,S : OCP.gp.gp_Sphere,Teta1 : float,Teta2 : float,Alpha1 : float,Alpha2 : float) -> None: ...
    @overload
    def Perform(self,S : OCP.gp.gp_Torus,Teta1 : float,Teta2 : float,Alpha1 : float,Alpha2 : float) -> None: ...
    def PrincipalProperties(self) -> GProp_PrincipalProps: 
        """
        Computes the principal properties of inertia of the current system. There is always a set of axes for which the products of inertia of a geometric system are equal to 0; i.e. the matrix of inertia of the system is diagonal. These axes are the principal axes of inertia. Their origin is coincident with the center of mass of the system. The associated moments are called the principal moments of inertia. This function computes the eigen values and the eigen vectors of the matrix of inertia of the system. Results are stored by using a presentation framework of principal properties of inertia (GProp_PrincipalProps object) which may be queried to access the value sought.
        """
    def RadiusOfGyration(self,A : OCP.gp.gp_Ax1) -> float: 
        """
        Returns the radius of gyration of the current system about the axis A.
        """
    def SetLocation(self,VLocation : OCP.gp.gp_Pnt) -> None: ...
    def StaticMoments(self) -> tuple[float, float, float]: 
        """
        Returns Ix, Iy, Iz, the static moments of inertia of the current system; i.e. the moments of inertia about the three axes of the Cartesian coordinate system.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,S : OCP.gp.gp_Cylinder,Alpha1 : float,Alpha2 : float,Z1 : float,Z2 : float,VLocation : OCP.gp.gp_Pnt) -> None: ...
    @overload
    def __init__(self,S : OCP.gp.gp_Cone,Alpha1 : float,Alpha2 : float,Z1 : float,Z2 : float,VLocation : OCP.gp.gp_Pnt) -> None: ...
    @overload
    def __init__(self,S : OCP.gp.gp_Sphere,Teta1 : float,Teta2 : float,Alpha1 : float,Alpha2 : float,VLocation : OCP.gp.gp_Pnt) -> None: ...
    @overload
    def __init__(self,S : OCP.gp.gp_Torus,Teta1 : float,Teta2 : float,Alpha1 : float,Alpha2 : float,VLocation : OCP.gp.gp_Pnt) -> None: ...
    pass
GProp_CenterMassX: OCP.GProp.GProp_ValueType # value = <GProp_ValueType.GProp_CenterMassX: 1>
GProp_CenterMassY: OCP.GProp.GProp_ValueType # value = <GProp_ValueType.GProp_CenterMassY: 2>
GProp_CenterMassZ: OCP.GProp.GProp_ValueType # value = <GProp_ValueType.GProp_CenterMassZ: 3>
GProp_InertiaXX: OCP.GProp.GProp_ValueType # value = <GProp_ValueType.GProp_InertiaXX: 4>
GProp_InertiaXY: OCP.GProp.GProp_ValueType # value = <GProp_ValueType.GProp_InertiaXY: 7>
GProp_InertiaXZ: OCP.GProp.GProp_ValueType # value = <GProp_ValueType.GProp_InertiaXZ: 8>
GProp_InertiaYY: OCP.GProp.GProp_ValueType # value = <GProp_ValueType.GProp_InertiaYY: 5>
GProp_InertiaYZ: OCP.GProp.GProp_ValueType # value = <GProp_ValueType.GProp_InertiaYZ: 9>
GProp_InertiaZZ: OCP.GProp.GProp_ValueType # value = <GProp_ValueType.GProp_InertiaZZ: 6>
GProp_Line: OCP.GProp.GProp_EquaType # value = <GProp_EquaType.GProp_Line: 1>
GProp_Mass: OCP.GProp.GProp_ValueType # value = <GProp_ValueType.GProp_Mass: 0>
GProp_None: OCP.GProp.GProp_EquaType # value = <GProp_EquaType.GProp_None: 4>
GProp_Plane: OCP.GProp.GProp_EquaType # value = <GProp_EquaType.GProp_Plane: 0>
GProp_Point: OCP.GProp.GProp_EquaType # value = <GProp_EquaType.GProp_Point: 2>
GProp_Space: OCP.GProp.GProp_EquaType # value = <GProp_EquaType.GProp_Space: 3>
GProp_Unknown: OCP.GProp.GProp_ValueType # value = <GProp_ValueType.GProp_Unknown: 10>



import OCP.PLib
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.TColgp
import OCP.TColStd
import OCP.Standard
import OCP.math
import OCP.GeomAbs
__all__  = [
"PLib",
"PLib_Base",
"PLib_DoubleJacobiPolynomial",
"PLib_HermitJacobi",
"PLib_JacobiPolynomial"
]
class PLib():
    """
    PLib means Polynomial functions library. This pk provides basic computation functions for polynomial functions. Note: weight arrays can be passed by pointer for some functions so that NULL pointer is valid. That means no weights passed.
    """
    @staticmethod
    def Bin_s(N : int,P : int) -> float: 
        """
        Returns the Binomial Cnp. N should be <= BSplCLib::MaxDegree().
        """
    @staticmethod
    @overload
    def CoefficientsPoles_s(Coefs : OCP.TColgp.TColgp_Array1OfPnt,WCoefs : OCP.TColStd.TColStd_Array1OfReal,Poles : OCP.TColgp.TColgp_Array1OfPnt,WPoles : OCP.TColStd.TColStd_Array1OfReal) -> None: ...
    @staticmethod
    @overload
    def CoefficientsPoles_s(Coefs : OCP.TColgp.TColgp_Array1OfPnt2d,WCoefs : OCP.TColStd.TColStd_Array1OfReal,Poles : OCP.TColgp.TColgp_Array1OfPnt2d,WPoles : OCP.TColStd.TColStd_Array1OfReal) -> None: ...
    @staticmethod
    @overload
    def CoefficientsPoles_s(Coefs : OCP.TColStd.TColStd_Array1OfReal,WCoefs : OCP.TColStd.TColStd_Array1OfReal,Poles : OCP.TColStd.TColStd_Array1OfReal,WPoles : OCP.TColStd.TColStd_Array1OfReal) -> None: ...
    @staticmethod
    @overload
    def CoefficientsPoles_s(dim : int,Coefs : OCP.TColStd.TColStd_Array1OfReal,WCoefs : OCP.TColStd.TColStd_Array1OfReal,Poles : OCP.TColStd.TColStd_Array1OfReal,WPoles : OCP.TColStd.TColStd_Array1OfReal) -> None: ...
    @staticmethod
    @overload
    def CoefficientsPoles_s(Coefs : OCP.TColgp.TColgp_Array2OfPnt,WCoefs : OCP.TColStd.TColStd_Array2OfReal,Poles : OCP.TColgp.TColgp_Array2OfPnt,WPoles : OCP.TColStd.TColStd_Array2OfReal) -> None: ...
    @staticmethod
    def ConstraintOrder_s(NivConstr : int) -> OCP.GeomAbs.GeomAbs_Shape: 
        """
        translates from Integer to GeomAbs_Shape
        """
    @staticmethod
    def EvalCubicHermite_s(U : float,DerivativeOrder : int,Dimension : int,ValueArray : float,DerivativeArray : float,ParameterArray : float,Results : float) -> int: 
        """
        Performs the Cubic Hermite Interpolation of given series of points with given parameters with the requested derivative order. ValueArray stores the value at the first and last parameter. It has the following format : Derivative array stores the value of the derivatives at the first parameter and at the last parameter in the following format first param last param
        """
    @staticmethod
    def EvalLagrange_s(U : float,DerivativeOrder : int,Degree : int,Dimension : int,ValueArray : float,ParameterArray : float,Results : float) -> int: 
        """
        Performs the Lagrange Interpolation of given series of points with given parameters with the requested derivative order Results will store things in the following format with d = DerivativeOrder
        """
    @staticmethod
    @overload
    def EvalLength_s(Degree : int,Dimension : int,U1 : float,U2 : float) -> tuple[float, float]: ...
    @staticmethod
    @overload
    def EvalLength_s(Degree : int,Dimension : int,U1 : float,U2 : float,Tol : float) -> tuple[float, float, float]: ...
    @staticmethod
    def EvalPoly2Var_s(U : float,V : float,UDerivativeOrder : int,VDerivativeOrder : int,UDegree : int,VDegree : int,Dimension : int) -> tuple[float, float]: 
        """
        Applies EvalPolynomial twice to evaluate the derivative of orders UDerivativeOrder in U, VDerivativeOrder in V at parameters U,V
        """
    @staticmethod
    def EvalPolynomial_s(U : float,DerivativeOrder : int,Degree : int,Dimension : int) -> tuple[float, float]: 
        """
        Performs Horner method with synthetic division for derivatives parameter <U>, with <Degree> and <Dimension>. PolynomialCoeff are stored in the following fashion
        """
    @staticmethod
    @overload
    def GetPoles_s(FP : OCP.TColStd.TColStd_Array1OfReal,Poles : OCP.TColgp.TColgp_Array1OfPnt) -> None: 
        """
        Get from FP the coordinates of the poles.

        Get from FP the coordinates of the poles.

        Get from FP the coordinates of the poles.

        Get from FP the coordinates of the poles.
        """
    @staticmethod
    @overload
    def GetPoles_s(FP : OCP.TColStd.TColStd_Array1OfReal,Poles : OCP.TColgp.TColgp_Array1OfPnt,Weights : OCP.TColStd.TColStd_Array1OfReal) -> None: ...
    @staticmethod
    @overload
    def GetPoles_s(FP : OCP.TColStd.TColStd_Array1OfReal,Poles : OCP.TColgp.TColgp_Array1OfPnt2d) -> None: ...
    @staticmethod
    @overload
    def GetPoles_s(FP : OCP.TColStd.TColStd_Array1OfReal,Poles : OCP.TColgp.TColgp_Array1OfPnt2d,Weights : OCP.TColStd.TColStd_Array1OfReal) -> None: ...
    @staticmethod
    def HermiteCoefficients_s(FirstParameter : float,LastParameter : float,FirstOrder : int,LastOrder : int,MatrixCoefs : OCP.math.math_Matrix) -> bool: 
        """
        This build the coefficient of Hermite's polynomes on [FirstParameter, LastParameter]
        """
    @staticmethod
    def HermiteInterpolate_s(Dimension : int,FirstParameter : float,LastParameter : float,FirstOrder : int,LastOrder : int,FirstConstr : OCP.TColStd.TColStd_Array2OfReal,LastConstr : OCP.TColStd.TColStd_Array2OfReal,Coefficients : OCP.TColStd.TColStd_Array1OfReal) -> bool: 
        """
        Compute the coefficients in the canonical base of the polynomial satisfying the given constraints at the given parameters The array FirstContr(i,j) i=1,Dimension j=0,FirstOrder contains the values of the constraint at parameter FirstParameter idem for LastConstr
        """
    @staticmethod
    def JacobiParameters_s(ConstraintOrder : OCP.GeomAbs.GeomAbs_Shape,MaxDegree : int,Code : int) -> tuple[int, int]: 
        """
        Compute the number of points used for integral computations (NbGaussPoints) and the degree of Jacobi Polynomial (WorkDegree). ConstraintOrder has to be GeomAbs_C0, GeomAbs_C1 or GeomAbs_C2 Code: Code d' init. des parametres de discretisation. = -5 = -4 = -3 = -2 = -1 = 1 calcul rapide avec precision moyenne. = 2 calcul rapide avec meilleure precision. = 3 calcul un peu plus lent avec bonne precision. = 4 calcul lent avec la meilleure precision possible.
        """
    @staticmethod
    def NivConstr_s(ConstraintOrder : OCP.GeomAbs.GeomAbs_Shape) -> int: 
        """
        translates from GeomAbs_Shape to Integer
        """
    @staticmethod
    def NoDerivativeEvalPolynomial_s(U : float,Degree : int,Dimension : int,DegreeDimension : int) -> tuple[float, float]: 
        """
        Same as above with DerivativeOrder = 0;
        """
    @staticmethod
    def NoWeights2_s() -> OCP.TColStd.TColStd_Array2OfReal: 
        """
        Used as argument for a non rational functions
        """
    @staticmethod
    def NoWeights_s() -> OCP.TColStd.TColStd_Array1OfReal: 
        """
        Used as argument for a non rational functions
        """
    @staticmethod
    def RationalDerivative_s(Degree : int,N : int,Dimension : int,All : bool=True) -> tuple[float, float]: 
        """
        Computes the derivatives of a ratio at order <N> in dimension <Dimension>.
        """
    @staticmethod
    def RationalDerivatives_s(DerivativesRequest : int,Dimension : int) -> tuple[float, float, float]: 
        """
        Computes DerivativesRequest derivatives of a ratio at of a BSpline function of degree <Degree> dimension <Dimension>.
        """
    @staticmethod
    @overload
    def SetPoles_s(Poles : OCP.TColgp.TColgp_Array1OfPnt,FP : OCP.TColStd.TColStd_Array1OfReal) -> None: 
        """
        Copy in FP the coordinates of the poles.

        Copy in FP the coordinates of the poles.

        Copy in FP the coordinates of the poles.

        Copy in FP the coordinates of the poles.
        """
    @staticmethod
    @overload
    def SetPoles_s(Poles : OCP.TColgp.TColgp_Array1OfPnt,Weights : OCP.TColStd.TColStd_Array1OfReal,FP : OCP.TColStd.TColStd_Array1OfReal) -> None: ...
    @staticmethod
    @overload
    def SetPoles_s(Poles : OCP.TColgp.TColgp_Array1OfPnt2d,FP : OCP.TColStd.TColStd_Array1OfReal) -> None: ...
    @staticmethod
    @overload
    def SetPoles_s(Poles : OCP.TColgp.TColgp_Array1OfPnt2d,Weights : OCP.TColStd.TColStd_Array1OfReal,FP : OCP.TColStd.TColStd_Array1OfReal) -> None: ...
    @staticmethod
    @overload
    def Trimming_s(U1 : float,U2 : float,Coeffs : OCP.TColgp.TColgp_Array1OfPnt,WCoeffs : OCP.TColStd.TColStd_Array1OfReal) -> None: ...
    @staticmethod
    @overload
    def Trimming_s(U1 : float,U2 : float,Coeffs : OCP.TColgp.TColgp_Array1OfPnt2d,WCoeffs : OCP.TColStd.TColStd_Array1OfReal) -> None: ...
    @staticmethod
    @overload
    def Trimming_s(U1 : float,U2 : float,Coeffs : OCP.TColStd.TColStd_Array1OfReal,WCoeffs : OCP.TColStd.TColStd_Array1OfReal) -> None: ...
    @staticmethod
    @overload
    def Trimming_s(U1 : float,U2 : float,dim : int,Coeffs : OCP.TColStd.TColStd_Array1OfReal,WCoeffs : OCP.TColStd.TColStd_Array1OfReal) -> None: ...
    @staticmethod
    def UTrimming_s(U1 : float,U2 : float,Coeffs : OCP.TColgp.TColgp_Array2OfPnt,WCoeffs : OCP.TColStd.TColStd_Array2OfReal) -> None: ...
    @staticmethod
    def VTrimming_s(V1 : float,V2 : float,Coeffs : OCP.TColgp.TColgp_Array2OfPnt,WCoeffs : OCP.TColStd.TColStd_Array2OfReal) -> None: ...
    def __init__(self) -> None: ...
    pass
class PLib_Base(OCP.Standard.Standard_Transient):
    """
    To work with different polynomial's BasesTo work with different polynomial's BasesTo work with different polynomial's Bases
    """
    def D0(self,U : float,BasisValue : OCP.TColStd.TColStd_Array1OfReal) -> None: 
        """
        Compute the values of the basis functions in u
        """
    def D1(self,U : float,BasisValue : OCP.TColStd.TColStd_Array1OfReal,BasisD1 : OCP.TColStd.TColStd_Array1OfReal) -> None: 
        """
        Compute the values and the derivatives values of the basis functions in u
        """
    def D2(self,U : float,BasisValue : OCP.TColStd.TColStd_Array1OfReal,BasisD1 : OCP.TColStd.TColStd_Array1OfReal,BasisD2 : OCP.TColStd.TColStd_Array1OfReal) -> None: 
        """
        Compute the values and the derivatives values of the basis functions in u
        """
    def D3(self,U : float,BasisValue : OCP.TColStd.TColStd_Array1OfReal,BasisD1 : OCP.TColStd.TColStd_Array1OfReal,BasisD2 : OCP.TColStd.TColStd_Array1OfReal,BasisD3 : OCP.TColStd.TColStd_Array1OfReal) -> None: 
        """
        Compute the values and the derivatives values of the basis functions in u
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def ReduceDegree(self,Dimension : int,MaxDegree : int,Tol : float) -> tuple[float, int, float]: 
        """
        Compute NewDegree <= MaxDegree so that MaxError is lower than Tol. MaxError can be greater than Tol if it is not possible to find a NewDegree <= MaxDegree. In this case NewDegree = MaxDegree
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def ToCoefficients(self,Dimension : int,Degree : int,CoeffinBase : OCP.TColStd.TColStd_Array1OfReal,Coefficients : OCP.TColStd.TColStd_Array1OfReal) -> None: 
        """
        Convert the polynomial P(t) in the canonical base.
        """
    def WorkDegree(self) -> int: 
        """
        returns WorkDegree
        """
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class PLib_DoubleJacobiPolynomial():
    def AverageError(self,Dimension : int,DegreeU : int,DegreeV : int,dJacCoeff : int,JacCoeff : OCP.TColStd.TColStd_Array1OfReal) -> float: ...
    def MaxError(self,Dimension : int,MinDegreeU : int,MaxDegreeU : int,MinDegreeV : int,MaxDegreeV : int,dJacCoeff : int,JacCoeff : OCP.TColStd.TColStd_Array1OfReal,Error : float) -> float: ...
    def MaxErrorU(self,Dimension : int,DegreeU : int,DegreeV : int,dJacCoeff : int,JacCoeff : OCP.TColStd.TColStd_Array1OfReal) -> float: ...
    def MaxErrorV(self,Dimension : int,DegreeU : int,DegreeV : int,dJacCoeff : int,JacCoeff : OCP.TColStd.TColStd_Array1OfReal) -> float: ...
    def ReduceDegree(self,Dimension : int,MinDegreeU : int,MaxDegreeU : int,MinDegreeV : int,MaxDegreeV : int,dJacCoeff : int,JacCoeff : OCP.TColStd.TColStd_Array1OfReal,EpmsCut : float) -> tuple[float, int, int]: ...
    def TabMaxU(self) -> OCP.TColStd.TColStd_HArray1OfReal: 
        """
        returns myTabMaxU;

        returns myTabMaxU;
        """
    def TabMaxV(self) -> OCP.TColStd.TColStd_HArray1OfReal: 
        """
        returns myTabMaxV;

        returns myTabMaxV;
        """
    def U(self) -> PLib_JacobiPolynomial: 
        """
        returns myJacPolU;

        returns myJacPolU;
        """
    def V(self) -> PLib_JacobiPolynomial: 
        """
        returns myJacPolV;

        returns myJacPolV;
        """
    def WDoubleJacobiToCoefficients(self,Dimension : int,DegreeU : int,DegreeV : int,JacCoeff : OCP.TColStd.TColStd_Array1OfReal,Coefficients : OCP.TColStd.TColStd_Array1OfReal) -> None: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,JacPolU : PLib_JacobiPolynomial,JacPolV : PLib_JacobiPolynomial) -> None: ...
    pass
class PLib_HermitJacobi(PLib_Base, OCP.Standard.Standard_Transient):
    """
    This class provides method to work with Jacobi Polynomials relatively to an order of constraint q = myWorkDegree-2*(myNivConstr+1) Jk(t) for k=0,q compose the Jacobi Polynomial base relatively to the weight W(t) iorder is the integer value for the constraints: iorder = 0 <=> ConstraintOrder = GeomAbs_C0 iorder = 1 <=> ConstraintOrder = GeomAbs_C1 iorder = 2 <=> ConstraintOrder = GeomAbs_C2 P(t) = H(t) + W(t) * Q(t) Where W(t) = (1-t**2)**(2*iordre+2) the coefficients JacCoeff represents P(t) JacCoeff are stored as follow:This class provides method to work with Jacobi Polynomials relatively to an order of constraint q = myWorkDegree-2*(myNivConstr+1) Jk(t) for k=0,q compose the Jacobi Polynomial base relatively to the weight W(t) iorder is the integer value for the constraints: iorder = 0 <=> ConstraintOrder = GeomAbs_C0 iorder = 1 <=> ConstraintOrder = GeomAbs_C1 iorder = 2 <=> ConstraintOrder = GeomAbs_C2 P(t) = H(t) + W(t) * Q(t) Where W(t) = (1-t**2)**(2*iordre+2) the coefficients JacCoeff represents P(t) JacCoeff are stored as follow:This class provides method to work with Jacobi Polynomials relatively to an order of constraint q = myWorkDegree-2*(myNivConstr+1) Jk(t) for k=0,q compose the Jacobi Polynomial base relatively to the weight W(t) iorder is the integer value for the constraints: iorder = 0 <=> ConstraintOrder = GeomAbs_C0 iorder = 1 <=> ConstraintOrder = GeomAbs_C1 iorder = 2 <=> ConstraintOrder = GeomAbs_C2 P(t) = H(t) + W(t) * Q(t) Where W(t) = (1-t**2)**(2*iordre+2) the coefficients JacCoeff represents P(t) JacCoeff are stored as follow:
    """
    def AverageError(self,Dimension : int,HermJacCoeff : float,NewDegree : int) -> float: ...
    def D0(self,U : float,BasisValue : OCP.TColStd.TColStd_Array1OfReal) -> None: 
        """
        Compute the values of the basis functions in u
        """
    def D1(self,U : float,BasisValue : OCP.TColStd.TColStd_Array1OfReal,BasisD1 : OCP.TColStd.TColStd_Array1OfReal) -> None: 
        """
        Compute the values and the derivatives values of the basis functions in u
        """
    def D2(self,U : float,BasisValue : OCP.TColStd.TColStd_Array1OfReal,BasisD1 : OCP.TColStd.TColStd_Array1OfReal,BasisD2 : OCP.TColStd.TColStd_Array1OfReal) -> None: 
        """
        Compute the values and the derivatives values of the basis functions in u
        """
    def D3(self,U : float,BasisValue : OCP.TColStd.TColStd_Array1OfReal,BasisD1 : OCP.TColStd.TColStd_Array1OfReal,BasisD2 : OCP.TColStd.TColStd_Array1OfReal,BasisD3 : OCP.TColStd.TColStd_Array1OfReal) -> None: 
        """
        Compute the values and the derivatives values of the basis functions in u
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def MaxError(self,Dimension : int,HermJacCoeff : float,NewDegree : int) -> float: 
        """
        This method computes the maximum error on the polynomial W(t) Q(t) obtained by missing the coefficients of JacCoeff from NewDegree +1 to Degree
        """
    def NivConstr(self) -> int: 
        """
        returns NivConstr

        returns NivConstr
        """
    def ReduceDegree(self,Dimension : int,MaxDegree : int,Tol : float) -> tuple[float, int, float]: 
        """
        Compute NewDegree <= MaxDegree so that MaxError is lower than Tol. MaxError can be greater than Tol if it is not possible to find a NewDegree <= MaxDegree. In this case NewDegree = MaxDegree
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def ToCoefficients(self,Dimension : int,Degree : int,HermJacCoeff : OCP.TColStd.TColStd_Array1OfReal,Coefficients : OCP.TColStd.TColStd_Array1OfReal) -> None: 
        """
        Convert the polynomial P(t) = H(t) + W(t) Q(t) in the canonical base.
        """
    def WorkDegree(self) -> int: 
        """
        returns WorkDegree

        returns WorkDegree
        """
    def __init__(self,WorkDegree : int,ConstraintOrder : OCP.GeomAbs.GeomAbs_Shape) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class PLib_JacobiPolynomial(PLib_Base, OCP.Standard.Standard_Transient):
    """
    This class provides method to work with Jacobi Polynomials relatively to an order of constraint q = myWorkDegree-2*(myNivConstr+1) Jk(t) for k=0,q compose the Jacobi Polynomial base relatively to the weight W(t) iorder is the integer value for the constraints: iorder = 0 <=> ConstraintOrder = GeomAbs_C0 iorder = 1 <=> ConstraintOrder = GeomAbs_C1 iorder = 2 <=> ConstraintOrder = GeomAbs_C2 P(t) = R(t) + W(t) * Q(t) Where W(t) = (1-t**2)**(2*iordre+2) the coefficients JacCoeff represents P(t) JacCoeff are stored as follow:This class provides method to work with Jacobi Polynomials relatively to an order of constraint q = myWorkDegree-2*(myNivConstr+1) Jk(t) for k=0,q compose the Jacobi Polynomial base relatively to the weight W(t) iorder is the integer value for the constraints: iorder = 0 <=> ConstraintOrder = GeomAbs_C0 iorder = 1 <=> ConstraintOrder = GeomAbs_C1 iorder = 2 <=> ConstraintOrder = GeomAbs_C2 P(t) = R(t) + W(t) * Q(t) Where W(t) = (1-t**2)**(2*iordre+2) the coefficients JacCoeff represents P(t) JacCoeff are stored as follow:This class provides method to work with Jacobi Polynomials relatively to an order of constraint q = myWorkDegree-2*(myNivConstr+1) Jk(t) for k=0,q compose the Jacobi Polynomial base relatively to the weight W(t) iorder is the integer value for the constraints: iorder = 0 <=> ConstraintOrder = GeomAbs_C0 iorder = 1 <=> ConstraintOrder = GeomAbs_C1 iorder = 2 <=> ConstraintOrder = GeomAbs_C2 P(t) = R(t) + W(t) * Q(t) Where W(t) = (1-t**2)**(2*iordre+2) the coefficients JacCoeff represents P(t) JacCoeff are stored as follow:
    """
    def AverageError(self,Dimension : int,JacCoeff : float,NewDegree : int) -> float: ...
    def D0(self,U : float,BasisValue : OCP.TColStd.TColStd_Array1OfReal) -> None: 
        """
        Compute the values of the basis functions in u
        """
    def D1(self,U : float,BasisValue : OCP.TColStd.TColStd_Array1OfReal,BasisD1 : OCP.TColStd.TColStd_Array1OfReal) -> None: 
        """
        Compute the values and the derivatives values of the basis functions in u
        """
    def D2(self,U : float,BasisValue : OCP.TColStd.TColStd_Array1OfReal,BasisD1 : OCP.TColStd.TColStd_Array1OfReal,BasisD2 : OCP.TColStd.TColStd_Array1OfReal) -> None: 
        """
        Compute the values and the derivatives values of the basis functions in u
        """
    def D3(self,U : float,BasisValue : OCP.TColStd.TColStd_Array1OfReal,BasisD1 : OCP.TColStd.TColStd_Array1OfReal,BasisD2 : OCP.TColStd.TColStd_Array1OfReal,BasisD3 : OCP.TColStd.TColStd_Array1OfReal) -> None: 
        """
        Compute the values and the derivatives values of the basis functions in u
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def MaxError(self,Dimension : int,JacCoeff : float,NewDegree : int) -> float: 
        """
        This method computes the maximum error on the polynomial W(t) Q(t) obtained by missing the coefficients of JacCoeff from NewDegree +1 to Degree
        """
    def MaxValue(self,TabMax : OCP.TColStd.TColStd_Array1OfReal) -> None: 
        """
        this method loads for k=0,q the maximum value of abs ( W(t)*Jk(t) )for t bellonging to [-1,1] This values are loaded is the array TabMax(0,myWorkDegree-2*(myNivConst+1)) MaxValue ( me ; TabMaxPointer : in out Real );
        """
    def NivConstr(self) -> int: 
        """
        returns NivConstr

        returns NivConstr
        """
    def Points(self,NbGaussPoints : int,TabPoints : OCP.TColStd.TColStd_Array1OfReal) -> None: 
        """
        returns the Jacobi Points for Gauss integration ie the positive values of the Legendre roots by increasing values NbGaussPoints is the number of points chosen for the integral computation. TabPoints (0,NbGaussPoints/2) TabPoints (0) is loaded only for the odd values of NbGaussPoints The possible values for NbGaussPoints are : 8, 10, 15, 20, 25, 30, 35, 40, 50, 61 NbGaussPoints must be greater than Degree
        """
    def ReduceDegree(self,Dimension : int,MaxDegree : int,Tol : float) -> tuple[float, int, float]: 
        """
        Compute NewDegree <= MaxDegree so that MaxError is lower than Tol. MaxError can be greater than Tol if it is not possible to find a NewDegree <= MaxDegree. In this case NewDegree = MaxDegree
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def ToCoefficients(self,Dimension : int,Degree : int,JacCoeff : OCP.TColStd.TColStd_Array1OfReal,Coefficients : OCP.TColStd.TColStd_Array1OfReal) -> None: 
        """
        Convert the polynomial P(t) = R(t) + W(t) Q(t) in the canonical base.
        """
    def Weights(self,NbGaussPoints : int,TabWeights : OCP.TColStd.TColStd_Array2OfReal) -> None: 
        """
        returns the Jacobi weights for Gauss integration only for the positive values of the Legendre roots in the order they are given by the method Points NbGaussPoints is the number of points chosen for the integral computation. TabWeights (0,NbGaussPoints/2,0,Degree) TabWeights (0,.) are only loaded for the odd values of NbGaussPoints The possible values for NbGaussPoints are : 8 , 10 , 15 ,20 ,25 , 30, 35 , 40 , 50 , 61 NbGaussPoints must be greater than Degree
        """
    def WorkDegree(self) -> int: 
        """
        returns WorkDegree

        returns WorkDegree
        """
    def __init__(self,WorkDegree : int,ConstraintOrder : OCP.GeomAbs.GeomAbs_Shape) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
